#
# spec file for package glibmm2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver -2_68-1
# Define a baseversion to ease updates
%define base_ver 2.68
# Define upstream name
%define _name glibmm

Name:           glibmm2
Version:        2.80.1
Release:        1.1
Summary:        C++ Interface for Glib
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.gtkmm.org/
Source0:        https://download.gnome.org/sources/glibmm/2.80/%{_name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  m4
BuildRequires:  meson >= 0.55.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.76.0
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(sigc++-3.0) >= 2.99.5

%description
Glibmm is the official C++ interface for the popular cross-platform
library Glib. It provides non-UI API that is not available in standard
C++ and makes it possible for gtkmm to wrap GObject-based APIs.

%package -n libglibmm%{so_ver}
Summary:        C++ Interface for Glib
Group:          System/Libraries

%description -n libglibmm%{so_ver}
Glibmm is the official C++ interface for the popular cross-platform
library Glib. It provides non-UI API that is not available in standard
C++ and makes it possible for gtkmm to wrap GObject-based APIs.

%package -n libgiomm%{so_ver}
Summary:        C++ Interface for Gio
Group:          System/Libraries

%description -n libgiomm%{so_ver}
Glibmm is the official C++ interface for the popular cross-platform
library Glib. It provides non-UI API that is not available in standard
C++ and makes it possible for gtkmm to wrap GObject-based APIs.

%package devel
Summary:        Development files for the Glib C++ API
Group:          Development/Libraries/C and C++
Requires:       libgiomm%{so_ver} = %{version}
Requires:       libglibmm%{so_ver} = %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}

%description devel
Glibmm is the official C++ interface for the popular cross-platform
library Glib. It provides non-UI API that is not available in standard
C++ and makes it possible for gtkmm to wrap GObject-based APIs.

%prep
%autosetup -p1 -n %{_name}-%{version}
chmod -x NEWS
chmod -x glib/glibmm/environ.h

%build
%meson \
	%{nil}
%meson_build

%check
# Temp disable test, currently needs internet during tests, disable until we figure out how to disable those
#%%meson_test

%install
%meson_install
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets -n libglibmm%{so_ver}
%ldconfig_scriptlets -n libgiomm%{so_ver}

%files -n libglibmm%{so_ver}
%license COPYING
%{_libdir}/libglibmm-%{base_ver}.so.*
%{_libdir}/libglibmm_generate_extra_defs-%{base_ver}.so.*

%files -n libgiomm%{so_ver}
%{_libdir}/libgiomm-%{base_ver}.so.*

%files devel
%doc ChangeLog NEWS README.md
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%{_libdir}/glibmm-%{base_ver}
%{_libdir}/giomm-%{base_ver}

%changelog
* Tue Aug 27 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.80.1:
  + Gio: Fix memory leak in DBus::generate_guid()
  + gmmproc:
  - generate_wrap_in.pl.in: Ignore -Winconsistent-dllimport from
    clang
  - Convert [enum@Module.Type.ENUMERATOR] in documentation
  - h2def.py: Avoid syntax warnings from Python 3.12
  - DocsParser.pm: Don't link to developer-old.gnome.org
  - Improve documentation of enum and enum class
  + Build: Some fixes to avoid warnings from the clang compiler
* Mon Mar 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.80.0:
  + Glib:
  - Add wide_from_utf8() and wide_to_utf8()
  - DateTime: Add create_from_local_usec(),
    create_from_utc_usec() and to_unix_usec().
  + Gio:
  - Application: Add get/set/property_version().
  - ApplicationCommandLine: Add done().
  - DBus::Message: Add get_arg0_path().
  - Socket: Add receive_bytes() and receive_bytes_from().
  - content_type_guess(): Remove most of an unnecessary overload.
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Fri Feb  2 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.78.1:
  + Glib: Dispatcher: Allow destroy during emit.
  + gmmproc: h2def.py: Make return types that are unsigned work.
  + Build:
  - Meson build: Don't fail if warning_level=everything
  - MSVC, NMake: Make dep paths configurable.
* Tue Sep 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.78.0:
  + Glib: ustring: Add a std::hash<> specialization. Not included
    by #include <glibmm.h>. Activate with #include
    <glibmm/ustring_hash.h>.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.76.0:
  + Glib:
  - Dispatcher:
    . Don't warn when a Dispatcher is deleted while messages are
    pending.
    . Add const versions of emit() and operator()() and deprecate
    the non-const versions.
  + Gio: ListModel: Add get_typed_object().
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.74.1:
  + Glib:
  - Binding: Fix the bind_property() with two transformation
    functions.
  - Dispatcher: Don't warn when a Dispatcher is deleted while
    messages are pending.
  + Gio:
  - NetworkMonitor::get_default(): Add refreturn.
  - ListStore: Rename a local variable.
  + Documentation: Glib::Binding::unbind(): Fix documentation.
  + gmmproc: generate_wrap_init.pl.in: Disable warning C4273 on
    Visual Studio.
  + Tests: Fix giomm_simple test on Windows.
  + Meson build:
  - Detect if we build from a git subtree.
  - Don't copy files with configure_file().
* Mon Sep 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.74.0:
  + Gio:
  - ListStore: Add find().
  - File: Add create_tmp().
  + Documentation: File: Document create_for_parse_name().
- Temp disable meson_test macro, tests now need internet during
  testrun.
* Mon Aug 29 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.73.2:
  + Glib: ustring: Add release()
  + Gio:
  - ListStore: Don't derive a gtkmm__GListStore GType
  - DBus::Proxy: get_connection(), get_interface_info(): Add
    refreturn
  - AppInfo: Add get_default_for_type_async/finish(),
    get_default_for_uri_scheme_async/finish()
  - File: Add make_symbolic_link_async/finish()
  - ListStore: Add property_n_items()
  - Resolver: Add lookup_by_name_with_flags(),
    lookup_by_name_with_flags_async/finish()
  + Documentation:
  - Glib::RefPtr: Improve the documentation
  - Gio::Action: Improve the documentation
  + gmmproc:
  - Improved handling of final types
  - Improve handling of gi-docgen syntax in C documentation
  + Build:
  - Meson build: Avoid unnecessary configuration warnings
  - Meson/MSVC: Add more warnings to ignore
  - NMake Makefiles: Ensure g[lib|io]mm[config.h|.rc] are created
  - Require glib-2.0 >= 2.73.2
- Use ldconfig_scriptlets macro for post(un) handling.
* Wed Aug 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.72.1:
  + Glib: ustring_Iterator: Don't declare copy constructor
    =default. A fix in the 2.72.0 release broke ABI.
- Changes from version 2.72.0:
  + Glib: MainContext: Add create(MainContextFlags flags).
  + Gio:
  - Add AppInfoMonitor
  - DBus::Proxy: signal_signal() accepts a signal name
  - File: Add move_async() and move_finish()
  - SocketClient: Deprecate
    set/get/property_tls_validation_flags()
  - TlsCertificate: Add properties private_key, private_key_pem,
    pkcs11_uri, private_key_pkcs11_uri. Fix the create*()
    methods.
  - TlsClientConnection.hg: Deprecate
    set/get/property_validation_flags().
  + gmmproc: Add "ignore_deprecations" argument in _WRAP_METHOD().
  + Build:
  - Require glib-2.0 >= 2.71.2.
  - MSVC build: Support VS2022 builds.
  - Meson build: Specify 'check' option in run_command(). Require
    Meson >= 0.55.0.
- Changes from version 2.70.0:
  + Glib:
  - Timer: Add resume() and is_active()
  - Add the Environ class
  - Binding: Add dup_source(), dup_target(). Deprecate
    get_source(), get_target(). TimeZone: Add operator bool(),
    create_identifier(). Deprecate create().
  + Gio:
  - FileInfo: Add get/set_access_date(), get/set_creation_date().
  - Notification: Add set_category().
  - TlsCertificate: Add property/get_not_valid_before(),
    property/get_not_valid_after(), property/get_subject_name(),
    property/get_issuer_name().
  - TlsConnection: Add property/get_protocol_version(),
    property/get_ciphersuite_name().
  + Tests: Add test of Glib::Environ
  + gmmproc: Handle gi-docgen syntax in C documentation.
  + Build: Require glib-2.0 >= 2.69.1.
* Thu Oct  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.68.2:
  + Glib: Replace all g_quark_from_static_string() by
    g_quark_from_string()
  + Gio:
  - FileEnumerator: Remove refreturn to avoid memory leak
  - ListModel::get_object(): Make it work for interface classes
  - AppInfo::get_all(): Avoid a crash on Windows
  + Build: MSVC build: Remove extraneous GLIBMM_API in
    Glib::ustring
* Tue Sep 28 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add m4 BuildRequires: the generated gmmproc actually stores the
  path to m4, as detected during build. Subsequent builds of other
  * mm modules from git need a working setup for this.
* Thu Jun 17 2021 Florian <sp1ritCS@protonmail.com>
- Update to version 2.68.1
  + Add dependencies to Doxygen tag files in subprojects
  + Doxygen in a main project shall not be called before tag files
    have been created or updated in subprojects.
  + Fix build as subproject without building documentation
  + meson.build: If mm-common-get is not found in maintainer-mode
    with 'required: false', try with 'required: true'.
    Don't try to use tag_file, if documentation is not built.
  + docs/reference/meson.build: Don't use variables from modules
    that don't define doxytagfile. These are subprojects that don't
    build their documentation.
  + Don't mark the Glib::Source class with GLIBMM_API
    Instead, mark the individual members with GLIBMM_API so that we
    avoid having the code tied to a particular STL and compiler
    version.
  + Update the classes that derive from Glib::Source accordingly as
    well
  + error.h Avoid exporting class deriving frm std::exception
    This will avoid having the ABI tied to a particular STL and
    compiler version, and so will eliminate C4275 compiler warnings
    when building the code.  Also update gerror.m4 so that it will
    generate code deriving from Glib::Error with the export macro
    markings with the member functions, so that things continue to
    build properly.
  + fileattributeinfo.hg: Avoid exporting classes with std::string
    members
  + variantdbusstring.h: Don't mark classes with GLIBMM_API
  + ustring.h: Avoid exporting classes with std::string members
  + Glib::PatternSpec: Ignore deprecation of g_pattern_match()
  + tests/glibmm_ustring_compare: Fix so it works for C++20
  + Meson build: Make quiet installations possible
  + Meson build: No implicit_include_directories
  + Variant: Fix so it works with C++20. C++20 changed some aspects
    of templates that broke variant.h on some compilers (GCC 11).
  + Meson build: No implicit_include_directories. It shall not be
    possible to find a glibmm header file with #include <xxx.h>
    instead of #include <glibmm/xxx.h>. Not fully fixed until
    https://github.com/mesonbuild/meson/issues/8562 has been fixed.
  + Add tools/defs_gen/enumextract.py. A Python script that can
    replace the Perl script tools/enum.pl.
  + Meson build: Make it possible to use glibmm as a subproject
    glib and sigc++ can be subprojects of glibmm.
  + Meson build: examples and tests: Add dependency('threads')
    Multithreaded examples and tests depend on 'threads'.
    I noticed this when I started experimenting with subprojects.
    Strange that it was not reported as a missing dependency long
    ago.
  + g[io|lib]mmconfig.h.*: Don't dllimport on MinGW. This will fix
    warnings when building items using glibmm and giomm with
    MinGW/GCC.
  + tools/gen_scripts: Ignore gio/gwin32api-*.h. Ignore some new
    glib header files when generating gio/src/gio_enums.defs and
    gio/src/gio_methods.defs.
  + docs/reference/Doxyfile.in: Remove obsolete entries
  + Meson build: Use relative paths to untracked/. The paths to the
    source code in untracked/ shall be relative to the meson.build
    file, when library files are built from a tarball. With
    absolute paths Meson may generate too long file names.
* Fri Dec 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.68.0:
  + Glib:
  - PropertyProxyConnectionNode::connect_changed(): Fix using
    without property name
  - Remove BalancedTree
  + Gio:
  - ListStore: Accept interfaces
  - MenuModel: Make MenuAttribute and MenuLink enum class
  - Add TlsClientConnectionImpl and TlsServerConnectionImpl
  - SocketClient::signal_event(): Fix wrapping of 'connection'
    parameter
  + gmmproc:
  - Add optional decl_prefix parameter to
    _WRAP_GERROR and _WRAP_ENUM. Used for adding GLIBMM_API or
    similar for MS Visual C++
  - Allow decorating comparison operators (for Visual Studio
    builds)
  - _CLASS_BOXEDTYPE, _CLASS_OPAQUE_COPYABLE: Fix move assignment
  - Decorate private generated classes with __declspec when
    building with Visual Studio
  - generate_wrap_init.pl.in:
    Use g_type_ensure(SomeClass::get_type()) to ensure that
    get_type() is called
  + Build:
  - Use __declspec(dllexport) consistently when building glibmm
    with Visual Studio
  - Meson build: Set default value of the 'warnings' option to
    'min'
  - Improve NMake support
  - Improve Visual Studio support
  - docs/reference/: Update for Doxygen >= 1.8.16
  - Meson build: Fix versioning on macOS
  - Meson build: Fix detection of macOS
  - Change the ABI to glibmm-2.68
  + Documentation: Meson build: Add missing Glib::Value and Variant
    documentation
- Bump so_ver, base_ver and in baselibs following upstream changes.
- Add meson BuildRequires and macros following upstreams port to
  meson build system.
- No longer package documentation, not built by default on meson.
* Sun Mar 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.65.3:
  + Tests: glibmm_buildfilename: Add some tests.
  + Build: Meson build: Install generate_extra_defs.h.
* Wed Mar 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.65.2:
  + Glib: Add missing #includes.
* Wed Mar 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.65.1:
  + Glib:
  - Add get_user_runtime_dir().
  - Add get_host_name().
  - MainContext: Add push/pop/get_thread_default().
  - Add StdStringView and UStringView. Use them in
    build_filename() and other functions
  - Regex::match(): Avoid using string after deletion.
  - Add Glib::canonicalize_filename().
  - Binding: get_source() and get_target() return ObjectBase*.
  - ustring: Fix insert(iterator, In, In).
  - Value: Adding static_assert() for template parameter.
  - Error: Derive from std::exception, remove Glib::Exception.
  - Binding: Keep a binding alive even without a RefPtr.
  + Gio:
  - DBus::Connection: Make the wrap() function thread-safe.
  - SettingsSchemaSource: Add list_schemas(). Add a create(),
    wrapping new_from_directory().
  - DBus::Message::get_unix_fd_list(): Add refreturn.
  + Tests:
  - Add glibmm_ustring_compare test.
  - Add glibmm_regex test.
  - Add glibmm_binding test.
  + gmmproc: Add optional decl_prefix parameter to
    _CLASS_BOXEDTYPE, _CLASS_BOXEDTYPE_STATIC, _CLASS_GOBJECT,
    _CLASS_INTERFACE, _CLASS_OPAQUE_COPYABLE,
    _CLASS_OPAQUE_REFCOUNTED, _WRAP_GERROR. Used for adding
    GLIBMM_API or similar for MS Visual C++.
  + Build:
  - Require glib-2.0 >= 2.6.
  - Change the ABI to glibmm-2.66.
  - Add Meson support.
  - Drop gendef from Windows builds.
  + Documentation:
  - Correct spelling of spawn_async_with_pipes().
  - Glib::Binding: Several doc improvements.
  - Glib::Binding: Explain why SlotTransform takes GValue*.
  - Gio::AsyncResult: Improve the class description.
- Bump so_ver, base_ver and baselibs following upstream changes.
* Thu Feb 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.63.1:
  + Glib:
  - ustring: Fix memory leak in make_valid().
  - Add ustring::sprintf(), wrapping g_strdup_printf().
  - Fix callback races in glibmm when GSource is destructed.
  - Checksum, Datetime, TimeZone: Declare as _CLASS_BOXEDTYPE.
  - Property: Add const get_proxy() returning ReadOnly
    Getting Proxy from ReadOnly is const.
  - Property: Update for compatibility with Gtk::Builder.
  - Fix memory leak in Variant<std::tuple<>>::create().
  - Remove TimeVal.
  + Gio:
  - Add Application::add_option_group().
  - DBus::Object: Fix refcounts in some vfuncs.
  - Gio::DBus: Add ObjectProxy, ObjectSkeleton, ObjectManager,
    ObjectManagerClient, ObjectManagerServer.
  - Drive, MountOperation, ThemedIcon, TlsDatabase,
    VolumeMonitor: Fix ownership of some lists and arrays
    (Fixes memory leaks and dangling pointers).
  - Add SocketControlMessage::add_deserialize_func().
  + gmmproc: Update for new glib deprecation macros.
  + Build:
  - Doxyfile.in: Remove unused configuration constants.
  - Require glib-2.0 >= 2.61.2.
  - Change the ABI to glibmm-2.64.
  + Documentation:
  - Glib::init(), Gio::init(): Improve the documentation.
  - Glib::ustring can't always replace std::string.
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop glibmm2 Provides and Obsoletes: Only glibmm2_4 compat
  package should provide this.
* Fri Aug 30 2019 mgorse@suse.com
- Update to version 2.61.1:
  + Glib:
  - Add DateTime::get_timezone()
  - Add KeyFile::get_locale_for_key()
  - Add TimeZone::get_identifier()
  - KeyFile: Make it a refcounted class
  - Add Value_RefPtrBoxed<>
  - Add Value<std::vector<string>> specializations and other
    Value
  - specializations that are necessary for _WRAP_PROPERTY
  + Gio:
  - Put _WRAP_VFUNC in protected sections
  - Add AppInfo::launch_uris_async() and launch_uris_async()
  - Add DBusConnection::get_flags()and property_flags()
  - TlsClientConnection: Remove property_accepted_cas()
  - ThemedIcon: Add create(const std::vector<Glib::ustring>&
  + iconnames:
  - Remove NO_GTYPE from some _WRAP_ENUMs
  - TlsConnection: Remove rehandshake API
  - Application: Add signal_name_lost()
  + Glib and Gio:
  - Use {} for function arguments initialisation
  - Issue glgo#GNOME/glibmm#20
  + gmmproc:
  - generate_wrap_init.pl.in: Don't exclude any Gtk classes
  - _WRAP_PROPERTY: generate a static_assert() that checks if
  - the data type is acceptable
  - Add _IS_REFCOUNTED_BOXEDTYPE
  - _WRAP_ENUM and _WRAP_GERROR: Add gtype_func parameter
  + Build:
  - glibmmconfig.h.in: Remove unused configuration constants
  - Change the ABI to glibmm-2.62
  + Documentation:
  - README: Add installation instructions
  - Don’t use @retval on out args, use @param[out]
- Update so_ver and base_ver
- Update versions in baselibs.conf
* Mon Dec  3 2018 bjorn.lie@gmail.com
- Update to version 2.59.1:
  + Glib:
  - ustring:
    . Fix wchar conversion on macOS with libc++.
    . Simplify format() using C++17 fold expression.
  - Avoid compiler warnings from function pointer conversions.
  + Gio:
  - Application: Add set_option_context_parameter_string(),
    set_option_context_summary(),
    set_option_context_description().
  - DesktopAppInfo: Add get_locale_string().
  - SocketClient: Take copy in RefPtrs for signal args.
  - Make SignalProxy_async_callback() available to e.g. gtkmm.
  + gmmproc: _WRAP_METHOD: Accept ":" in slot_callback parameter.
  + Build:
  - Require C++17.
  - Require glib-2.0 >= 2.55.1
  - Replace the Visual Studio project files with MSVC NMake
    project files.
  - Change the ABI to glibmm-2.60.
  + Documentation: Use libsigc++-3.0.tag for libsigc++
    documentation.
- Bump soname following upstreams changes.
* Tue Apr 17 2018 dimstar@opensuse.org
- Export CXXFLAGS="-std=c++17" until upstream makes this the
  default again. Needed, as libsigc++-3.0 moved to C++17.
* Tue Mar 27 2018 luc14n0@linuxmail.org
- Update to version 2.57.1:
  + Gio: DataOutputStream::put_string(): Don't pass std:string by
    value.
  + gmmproc: Add _MEMBER_SET_STR() macro (bgo#793778).
- Update baselibs.conf to 2.58 following upstream ABI changes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb 22 2018 luc14n0@linuxmail.org
- Update to version 2.55.2:
  + Glib:
  - IOCondition: Add an IO_ prefix to the enumerator names;
  - TimeoutSource: Use monotonic time consistently (bgo#792524);
  - Ustring:
    . Replace 8×format() and 9×compose() with 1 respective
    variadic template;
    . Use std::initializer_list instead of pointer + size
    (bgo#784211).
  - VariantBase:
    . Add operator==() and operator!=() (bgo#789330);
    . cast_dynamic(): Remove noexcept(false).
  + Glib::Gio:
  - AppInfo: Update the name of the AppLaunchContext parameters;
  - Application: Fix property_resource_base_path()'s type;
  - DataInputStream:
    . Remove read_until*();
    . Fix the documentation of read_line_utf8().
  - InetSocketAddress, ProxyAddress: No guint16 in
    _WRAP_PROPERTY();
  - Settings: set_int() and friends shall return bool
    (bgo#784211);
  - TlsClientConnection: Remove get/set/property_use_ssl3().
  + gmmproc:
  - Warn if parameter lists are not compatible;
  - _WRAP_METHOD_DOCS_ONLY: Optionally suppress @return section.
    (bgo#787978).
  - docextract_to_xml.py: Add --exclude-file option.
  - Suppress the @return section if return type is void.
  - generate_extra_defs.cc:
  - Write signal flags to .defs files.
  - Write default values of properties to .defs files.
  - Write default values of properties to generated
    documentation (bgo#785895).
  - Warn for unmatched deprecations in signals and properties.
  + Update documentation.
- Change License tag to LGPL-2.1-or-later complying with SPDX 3.0.
* Fri Sep  8 2017 jengelh@inai.de
- Repair duplicated package summaries.
  Do not run fdupes across hardlink boundaries.
* Fri Aug 25 2017 zaitor@opensuse.org
- Update to version 2.55.1:
  + Glib:
  - Object: Value_Pointer class should take only one template
    argument.
  - Variant: Improved support for D-Bus object paths and
    signatures (bgo#785700).
  - Glib::Value_Flags<>: static_cast to correct type.
  + Gio:
  - Derive all interfaces directly from Glib::Interface
    (bgo#776537).
  - Application: OptionType: Make this an enum class.
  - BufferedInputStream, BufferedOutputStream, DataOutputStream:
    Implement Seekable.
  - CharsetConverter: Implement the Gio::Initable interface and
    call Initable::init() from CharsetConverter's constructor
    (bgo#776537).
  - Add FileDescriptorBased interface and make GUnixInputStream
    and GUnixOutputStream implement it.
  - MemoryInputStream, UnixInputStream: Implement
    PollableInputStream.
  - MemoryOutputStream, UnixOutputStream: Implement
    PollableOutputStream.
  - TlsDatabase: create_certificate_handle_vfunc(): Fix memory
    leak, and correctly return nulltpr (bgo#783360).
  + gmmproc:
  - Accept curly braces in default values in _WRAP macros
    (bgo#783216).
  - Don't accept unpaired double quotes.
  - gmmproc: Fix _WRAP_ENUM for enumerators with apostrophes.
  - gmmproc, _WRAP_ENUM: Add optional CONV_TO_INT parameter.
  + Build:
  - Change the ABI to glibmm-2.56.
  - Really exclude DesktopAppInfo from wrap_init.cc on MacOS
    (bgo#781947).
  + Documentation:
  - miscutils: Update docs of get_*_name() from GLib.
  - Fix documentation of enum Glib::IOCondition.
- Bump so_ver and base_ver following upstream changes, also done
  for baselibs.conf, following this, also rename sub-packages.
- Run spec-clean, modernize spec.
* Tue May 30 2017 zaitor@opensuse.org
- Update to version 2.53.2:
  + Glib: ConstructParams: Do not increment allocation size twice.
  + Gio:
  - ActionMap: Really fix add_action_with_parameter()
    (bgo#774444).
  - UnixSocketAddress::create(): Remove a default value to avoid
    ambiguity (bgo#782592).
  + Gio::DBus: Proxy: Wrap call() and call_sync() methods
    (bgo#781818).
  + gmmproc: Use of static_cast<> instead of C-style casts.
  + Build:
  - Fix the build on MacOS, where glib doesn't have gdesktopinfo
    (bgo#781947).
  - Really use desktopappinfo.hg to fix the build.
  + Documentation:
  - Glib, Gio: Update documentation of in-class enums.
  - ActionMap: Improve add_action_with_parameter docs.
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 2.53.1.1:
  + Glib:
  - Use C++11 enum classes instead of old-style enums, and put
    many enums inside relevant class declarations.
  - RefPtr: Make this an alias for std::shared_ptr<> instead
    (bgo#755037).
  - Remove Glib::WeakRef. Use std::weak_ref<> instead
    (bgo#755037).
  - Object: Use g_object_new_with_properties() instead of
    (deprecated) g_object_newv() and (deprecated) GParameter.
  - IOChannel: Avoid creating a RefPtr to this (bgo#755037).
  - SignalProxy: connect(): Signals with non-void return values
    now have no default value for the "after" parameter, forcing
    application developers to think about whether they should
    connect before or after already-connected signal handlers,
    and default signal handlers. This is awkward but necessary.
    Just provide "true" to get the previous behaviour, or use
    connect_notify(). connect_notify(): Signals with void return
    values have no connect_notify(), because it is not useful
    with those signals (bgo#126213).
  + Gio:
  - Use C++11 enum classes instead of old-style enums, and put
    many enums inside relevant class declarations.
  - Remove duplicate ErrorEnum declaration.
  + ConstructParams:
  - Remove (hopefully really unnecessary) copy constructor.
  - C++11: =delete the operator=, instead of making it private.
  + Value:
  - Remove the CType alias, which should be unnecessary.
  - value_custom: Replace a template parameter with C++11 type
    traits.
  - Value<RefPtr<T>>: Only use this specialization if T has
    get_base_type() (bgo#755037).
  + Variant:
  - operator bool(): Simplify to avoid clang++ warnings.
  - C++11: Variant: Replace throw(std::bad_cast) with
    noexcept(false) (rh#1438766).
  + Socket: Avoid creating a RefPtr to this (bgo#755037).
  + Gio:DBus:
  - Use C++11 enum classes instead of old-style enums, and put
    many enums inside relevant class declarations.
  + gmmproc:
  - _WRAP_ENUM(): Generate C++ enum classes instead of enums,
    and let the enums be inside class declarations (bgo#86864).
  + Build: Windows:  Visual Studio builds: Update ABI version.
- Changes from version 2.53.1:
  + Glib:
  - OptionGroup:
    . Don't allow copy or move.
    . Remove the OptionGroup& parameter in on_pre_parse(),
    on_post_parse() and on_error().
  - IOChannel, StreamIOChannel: Remove deprecated parts.
  - ustring: Add make_valid() (bgo#780075).
  - Remove (unused) Sequence and sequence().
  - Remove ListHandle, SListHandle, ArrayHandle, SArrayHandle,
    and StringArrayHandle, replacing them with std::vector in
    API.
  + gmmproc: _WRAP_METHOD(): Some more use of auto in generated
    code.
  + Build:
  - Change the ABI to glibmm-2.54.
  - Add some #include directives.
  - Visual Studio: Require Visual Studio 2017 and update the
    glibmm project.
- Bump so_ver to -2_54-1 in spec and baselibs.conf following
  upstream changes.
- Add a new base_ver define and set it to 2.54 to ease future
  version updates.
* Tue Mar 14 2017 dimstar@opensuse.org
- Update to version 2.51.5:
  + Gio:
  - Application: get_default(): Correct the reference counting.
    (bgo#779936).
  - Add PropertyAction.
  + Glib:
  - Remove Glib::unconst() because it is unused and unnecessary.
  - Variant: Add template specialization for std::tuple, and a
    test (bgo#777791).
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 2.51.2:
  + Glib: Object construction: Add custom class init and instance
    init functions. An extra class init function is useful in
    Gtk::WidgetCustomDraw and Gtk::WidgetCustomSnapshot
    (bgo#775348).
  + Gio:
  - Action: #include <glibmm/variant.h>, for convenience
    (bgo#777953).
  - SimpleAction: Make set_state() public (bgo#777953).
  + Documentation: Glib::Variant: Explain how to create "maybe"
    type (bgo#778219).
* Wed Jan 11 2017 zaitor@opensuse.org
- Update to version 2.51.1.2:
  + Glib:
  - Remove some deprecated API.
  - Variant: Remove the string specializations of cast_dynamic.
  - Glib::VariantType: Add get_item_types(), removing first() and
    next() (bgo#775741).
  + Gio:
  - init(): Set the global locale (bgo#661588).
  - ActionBase: get_state_hint_variant() now returns
    VariantContainerBase.
  - ActionMap: add_action_with_parameter(): Register the
    parameter type, to make this work (bgo#774444).
  - ActionResult: Add is_tagged_vfunc().
  - Glib::Dispatcher: Implement the pimpl idiom (bgo#651942).
  - File, FileInfo, FileIOStream, FileOutputStream: Use
    Glib::ustring for (UTF-8) file attributes of string type
    (bgo#615950).
  - NetworkMonitor: Derive from Gio::Initable.
  - RemoteActionGroup: Rename some vfuncs to add _full().
  + Documentation:
  - ActionMap:
    . ActivateSlot: Mention add_action_bool().
    . ActivateWithParameterSlot: Be more specific (bgo#774444).
  + Build:
  - Update the Visual Studio project files.
  - Some minor cppcheck fixes.
* Wed Dec  7 2016 dimstar@opensuse.org
- Update to version 2.51.1.1:
  + General:
  - Remove no_default_handler in some _WRAP_SIGNAL()s.
  - Build: examples/Makefile.am: Re-insert the dispatcher
    examples.
  + Glib:
  - Dispatcher: Don't cast a HANDLE to an int on Windows
    (bgo#772074).
  - ObjectBase:
    . Remove connect_property_changed_with_return() and let
    connect_property_changed() return a sigc::connection.
    . Use std::forward_list for interface class pointers.
    . Replace extra_object_base_data map by instance data.
  - ObjectBase: overload get_property().
  - Main, IOSource: autodeduce type of fd field (bgo#770274).
  - Settings:
    . Add property_settings_schema(), and update
    signal_changed().
    . Make set_enum() + set_flags() usable (bgo#774647).
  - SettingsSchemaKey: Add missing value/range methods
    (bgo#774903).
  - SignalProxyNormal: Remove connect_() and connect_notify_(),
    adding connect_impl().
  - Rename SignalProxyDetailed to SignalProxyDetailedBase, and
    SignalProxyDetailedAnyType to SignalProxyDetailed.
    Remove SignalProxyDetailed# aliases (# = 0..6).
  - Source: Replace extra_source_data by instance data
    (bgo#561885).
  + Gio:
  - ActionMap::add_action_vfunc(): Const correction.
  - Application: Add dbus_register/unregister_vfunc (bgo#762191).
  - Menu: insert/prepend/add_item(): Const correction.
  - MenuAttributeIter: get_value(): Const correction.
  - MenuModel: get_item_atribute(): const correction.
  - RemoteActionGroup: Derive from Gio::ActionGroup.
  + Gio::Dbus:
  - Proxy: Fix memory leak in get_cached_property_names()
    (bgo#775210).
  - Proxy: Derive from (and implement) Gio::DBus::Interface.
* Sat Dec  3 2016 jengelh@inai.de
- Rectify RPM groups, replace old macros.
* Fri Dec  2 2016 dimstar@opensuse.org
- Update to version 2.51.1:
  + This is the first release of the glibmm-2.52 API/ABI.
  + Require C++14.
  + Use libsigc++-3.0 instead of libsigc++-2.0.
  + Remove lots of deprecated API.
  + Gio:
  - BufferedInputStream, InputStream, OutputStream: Add vfuncs,
    allowing implementation in C++ (bgo#572471).
  - SettingsSchemaSource::get_default(): Correct the reference
    count (bgo#774593).
  - Settings: Fix type of 'key' parameter of
    writable-change-event signal (bgo#773977).
  + Glib: ustring: Add cbegin() and cend().
- Change so_ver to -2_52-1, following upstream.
- No longer provide/obsolete glibmm24(-devel): this is now done by
  the new glibmm2_4 package.
- Replace pkgconfig(sigc++-2.0) BuildRequires with
  pkgconfig(sigc++-3.0), following upstream.
* Tue Sep 20 2016 dimstar@opensuse.org
- Update to version 2.50.0:
  + No changes since 2.49.7.
* Wed Sep 14 2016 dimstar@opensuse.org
- Update to version 2.49.7:
  + Gio:
  - AppInfo: Add launch_default_for_uri_async().
  - Application::get_busy(): return the bool (bgo#770304).
  - Drive: Add is_removable().
  - Settings:
    . set_uiint(): Deprecate for set_uint().
    . Add get/set_uint64().
    . Add get/set_int64().
  - giomm.h: Add include for settingsschemasource.h
  + Documentation: Glib::OptionGroup: Improve the documentation of
    add_entry().
* Fri Aug 19 2016 zaitor@opensuse.org
- Update to version 2.49.5:
  + Glib: OptionContext: Wrap g_option_context_parse_strv().
  + gmmproc:
  - Add DocsParser::remove_c_memory_handling_info().
  - Add missing objects to glib/gio_extra_objects.defs.
  - Remove DocsParser::non_object_method_name().
  - swap() implementations: Use std::swap().
  + Documentation: Gio::SocketService: Update the class
    documentation.
* Thu Jul 21 2016 zaitor@opensuse.org
- Update to 2.49.4:
  + glib: Replace some use of some deprecated libsigc++ API.
  + Build: Really enable silent builds (bgo#768797).
* Mon Jun 27 2016 zaitor@opensuse.org
- Update to version 2.49.2:
  + Gio:
  - FilterInputStream: Added a constructor (bgo#572471).
  - FilterOutputStream: Correct the property_base_stream()
    return type (bgo#572471, bgo#572471).
  - InputStream: Added a constructor, is_closed(), has_pending(),
    set_pending(), clear_pending() (bgo#572471).
  - OutputStream: Added a constructor, is_closed(), is_closing(),
    has_pending(), set_pending(), and clear_pending()
    (bgo#572471).
  - Pollable, InputStream, OutputStream: Return -1 on error in
    vfuncs.
  + gmmproc:
  - Make h2def.py recognize some GDK_PIXBUF macros.
  - Add optional argument err_return_value in _WRAP_VFUNC.
  + Build: Visual Studio build files: Update projects.
* Thu Jun  2 2016 zaitor@opensuse.org
- Update to version 2.49.1:
  + gmmproc:
  - Discard unused m4 sections.
  - Add 'deprecated' option in _WRAP_ENUM and _WRAP_GERROR.
  - _CLASS_GOBJECT(): Allow custom move operation implementations
    with _CUSTOM_MOVE_OPERATION() (bgo#756593).
  + Gio:
  - Added ListModel, ListStoreBase and ListStore<>, and tests
    (bgo#755307).
  - SocketAddress: Correct the constructor's implemention
    (bgo#766150).
  + Gio:DBus: Proxy: allow using GDBusProxy* conversion outside
    DBus namespace.
  + Glib:
  - FileAtrributeInfoList, Checksum, Module, RefPtr: Make
    operator bool explicit.
  - Property: Allow to set property nick, blurb, and flags
    (bgo#755256).
  - VariantBase: Add explicit operator bool(), deprecating
    operator const void*.
  + Documentation: Examples: Use libsigc++ 2.9/10 and its
    slot/signal<R(Args...)> syntax.
* Fri Apr 15 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Thu Mar 31 2016 zaitor@opensuse.org
- Update to version 2.48.1:
  + MacOS X: Add alternative #ifdefed code when thread_local is not
    supported by the compiler (bgo#759791).
  + Replace most typedefs with the C++11 using keyword.
* Tue Mar 29 2016 zaitor@opensuse.org
- Update to version 2.48.0:
  + Regenerate docs.xml files.
  + Regenerate gio .defs.
* Fri Mar 18 2016 dimstar@opensuse.org
- Update to version 2.47.92:
  + Adapt to libsigc++-2.0 2.8:
  - using only the non-deprecated sigc::mem_fun() API.
  - using std::ref instead of deprecated sigc::ref.
  - Correct bad uses of sigc::bind<1>.
  + gmmproc:
  - defs generation: Mark deprecated signals and properties as
    such in the generated .defs file.
  - gmmproc: Check if signals and properties are deprecated
    appropriately.
  + Build:
  * MSVC builds: Look for includes in include/gio-win32-2.0.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 2.47.6:
  + Glib:
  - Add and uses Glib::c_str_or_nullptr() (bgo#755245).
  - Add some connect() overloads that move the sigc::slot.
  - Fix definition of VARIANT_TYPE_DICT_ENTRY to match header
    declaration (bgo#761046).
  - Replace, via deprecation, ScopedPtr with
    make_unique_ptr_gfree() (bgo#760223).
  - SignalProxy: use variadic templates.
  - ustring: Add move operators (bgo#760282).
  - Put deprecation ifdefs around aleady-deprecated
    GLIBMM_INITIALIZE_STRUCT.
  + Gio:
  - FileInfo::list_attributes(): Make name_space optional.
  - Icon: Add serialize(), deserialize() and documentation of
    create().
  - PropertyBase: Make custom properties more flexible
    (bgo#731484).
  - SocketConnectable: Add to_string().
  + Gio::DBus:: Connection: Pass an empty bus name as nullptr.
  + gmmproc:
  - Fix errthrow in _WRAP_VFUNC (bgo#762437).
  - Add NULL option to _WRAP_METHOD.
  - h2def.py: Accept parameter names beginning with const.
  + Build:
  - Use some more minor C++11 features.
  - Threads example: Fix build on Visual Studio (bgo#760612).
  - glibmmconfig.h.in: Fix Visual Studio 2013 builds
    (bgo#760612).
  - Glib::ustring: fix -Wmisleading-indentation gcc 6 warning in
    public header (bgo#760641).
  + Other: Reformat our hand-written C++ code with clang-format.
* Sun Dec 20 2015 damjanovic.ivo@gmail.com
- Update to version 2.47.7:
  + Glib:
  - ustring: Don't allow comparison to 0 (bgo#572978).
  + Gio:
  - ActionMap: Fix the ref count in lookup_action_vfunc()
    (bgo#758813).
  + Build:
  - Dispatcher: #include <mutex> in Windows builds
    (bgo#758894).
  - Gio::Application: Destructor: Use noexcept in the
    implementation too (bgo#758798).
  - Fix the build with --disable-deprecated-api.
* Sun Nov 29 2015 zaitor@opensuse.org
- Update to version 2.47.3.1:
  + Use thread_local instead of (deprecated)
    Glib::Threads::Private.
- Changes from version 2.47.3:
  + Deprecate all of Glib::Threads, including Mutex, Lock, Thread,
    etc.
  + Deprecated Glib::ThreadPool.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 2.46.2:
  + ObjectBase, Object, Interface: Correct move constructors and
    move assignment operators (bgo#756962).
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 2.46.1:
  + mmmproc: _CLASS_GOBJECT(): Move the "= delete"ed constructor
    and operator= to public, instead of private.
- Changes from version 2.46.0:
  + Glib::
  - RefPtr: Make it possible to stop use of RefPtr with certain
    classes (bgo#755048).
  - WeakRef: Use noexcept (bgo#583399).
  + Gio: Application: Remove bind/unbind_busy_property() because
    they are not quite ready.
  + Gio::Dbus: Connection::signal_subscribe(): Pass nullptr instead
    of "".
* Fri Sep 18 2015 zaitor@opensuse.org
- Update to version 2.45.80:
  + Gio:
  - Application: Add bind/unbind_busy_property() and
    set_state_hint().
  - TlsClientConnection: Add copy_session_state().
  + Build:
  - MSVC Builds:
    . Require MSVC.Net 2013 for C++11 support (bgo#753271).
    . Adapt for recent source code changes (bgo#753271).
    . Improve Build Speed and Debugging Experience.
* Fri Sep 11 2015 dimstar@opensuse.org
- Add patch tags.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 2.45.70:
  + Glib:
  - C++11:
    . Add move operations to ObjectBase and Object.
    . RefPtr: Make methods noexcept.
  + gmmproc:
  - C++11:
    . Generate move operations.
    . More use of = delete instead of private copy operations.
    . Use std::stoul instead of strtoul.
  - C++11: IOChannel: move operations: Call the base
    sigc::trackable.
  - C++11: Markup: Add move operations.
  + Documentation:
  - Update configuration for Doxygen 1.8.9.1.
  - Exclude bogus documentation symbols.
  - Generate documentation for API all platforms.
- Changes from version 2.45.52:
  + Glib::
  - C++11: Glib::ObjectBase, Object, Interface: Add move
    operators.
  - C++11: Mark all _CLASS_OPAQUE_REFCOUNTED classes as final.
  + Gio: FileIcon: Remove unncessary IMPLEMENTS_INTERFACE.
  + gmmproc:
  - _CLASS_GOBJECT(): Generate move operations.
  - _CLASS_INTERFACE(): Generate move operations.
  - _CLASS_BOXEDTYPE_STATIC(): Add move operations.
  - _CLASS_BOXEDTYPE_STATIC: Add explicit copy operations.
  - _CLASS_OPAQUE_COPYABLE(): Add move operations.
  - _CLASS_OPAQUE_COPYABLE: Generate static swap().
  - _CLASS_OPAQUE_REFCOUNTED: Use = delete for the default
    constructor.
* Thu Aug 20 2015 zaitor@opensuse.org
- Update to version 2.45.50:
  + Glib: RefPtr:
  - Add move constructor and move assignment operator for
    castable types (bgo#752812).
  - Add release(): (bgo#752812).
  - move assignment operator: Use swap() (bgo#752812).
  + Gio:
  - NetworkMonitor: Add get_network_metered() and property.
  - SocketService: Add active property.
  + General: C++11: Boxed types: Declare move operations as
    noexcept.
  + Build:
  - Update Visual Studio project to Visual Studio 2013, for C++11
    support.
  - Improve gen_scripts.
  + gmmproc: generate_wrap_init.pl: Allow use of nested namespaces
    for whole module (bgo#753013).
* Fri Jul 31 2015 zaitor@opensuse.org
- Update to version 2.45.40:
  + Glib: RefPtr: Add move constructor and move assignment
    operator.
  + Gio: Application: Add the shutdown signal (bgo#752600).
  + Build:
  - C++11:
    . Use noexcept instead of throw().
    . Use "= delete" instead of private copy
    constructors/operator=.
    . Use nullptr instead of 0.
    . C++11: Use the override keyword.
- Changes from version 2.45.31:
  + Glib: HelperList: fix iterator check in operator[]
    (bgo#751530).
  + Build:
  - Use (and require) C++11.
  - Use some simple C++11 syntax.
  - Fix the build with -Wshadow.
  + gmmproc:
  - Generate code that uses some simple C++11 syntax.
  - _WRAP_SIGNAL: Accept apostrophes in a preceding comment.
- Changes from version 2.45.3:
  + Add SettingsSchema, SettingsSchemaKey and SettingsSchemaSource.
  + Deprecate HelperList and SArray because nothing uses them.
  + Build: Don't disable more deprecation warnings than necessary
    (bgo#750379).
  + gmmproc:
  - _WRAP_METHOD: deprecated: Use
    G_GNUC_[BEGIN|END]_IGNORE_DEPRECATIONS per function, instead
    of one big undef [G|GDK|GTK]_DISABLE_DEPRECATED (bgo#750379).
  - Remove GP_LIST, because nothing uses it.
- Drop fix-deprecated-extra_object_base_data_mutex-auto_ptr.patch:
  Fixed upstream.
* Fri Jul 31 2015 novell@tower-net.de
- Added fix-deprecated-extra_object_base_data_mutex-auto_ptr.patch
  + fixes gcc5 warning: ‘template<class> class std::auto_ptr’ is
    deprecated [-Wdeprecated-declarations]
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 2.44.0:
  + Gio: Action, ActionGroup: Avoid memory leaks in funcs
    (bgo#705124).
  + gmmproc: _WRAP_VFUNC(): Add keep_return parameter (bgo#705124).
* Sat Mar  7 2015 zaitor@opensuse.org
- Update to version 2.43.91:
  + Glib: OptionContext: Add get/set_strict_posix().
  + Gio: Application:
  - Add get/set/unset_resource_base_path() and property.
  - Add get_is_busy() and property.
  + File: Add replace_contents_bytes_aync().
  + InputStream: Add read_all_async() and read_all_finish().
  + MemoryInputStream: Add add_bytes().
  + OutputStream: Add write_all_async() and write_all_finish().
  + Gio::DBus InterfaceInfo: Add cache_build() and cache_release().
* Sat Feb 28 2015 dimstar@opensuse.org
- Update to version 2.43.90:
  + Glib:
  - Error::register_init(): Call Glib::wrap_register_init().
    (bgo#743466).
  - OptionGroup:
    . Fix enable/disable bool option pairs (bgo#744854).
    . Fix memory leaks (bgo#745173).
    . Don't use deprecate g_option_group_free().
  - Value: Deprecate Value<char>, add Value<signed char>.
  + Gio:
  - Application: Deprecate property_action_group().
  - Notification: Add set_priority() and enum
    NotificationPriority.
  - Add TcpWrapperConnection.
  - UnixSocketAddress: Deprecate property_abstract().
  + gmmproc:
  - Fix error messages in glib and gio by removing unnecessary
    _IGNORES().
  - h2def.py: Remove *_DEPRECATED_IN_*_*_FOR(*) prefixes with
    white space.
  - Put DOXYGEN_SHOULD_SKIP_THIS around *_Class prototypes
    (bgo#743918).
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 2.43.3:
  + Glib:
  - Binding: Rename and change BindingTransformSlot to
    SlotTransform. (bgo#738663).
  - Add SlotSpawnChildSetup (bgo#528285).
  + Documentation: Resource: Suppress incorrect doxygen links.
* Sun Dec 21 2014 zaitor@opensuse.org
- Update to version 2.43.2:
  + Gio:
  - Added NetworkMonitor.
  - UnixFDList, UnixFDMessage: Correct array lengths in
    steal_fds() (bgo#741365).
  + gmmproc:
  - Don't make one very long line for the enum documentation.
  - Improve the conversion of Since to @newin.
  - Add an empty line after @newin where it's missing.
- Changes from version 2.43.1:
  + gmmproc:
  - Tidy up the generation of enum docs.
  - _WRAP_GERROR: Add documentation to the generated enum Code.
  - Change messages that MS Visual Studio can misunderstand.
  - Warn when an ignored method or signal doesn't exist
    (bgo#737212).
  + Glib:
  - Add Binding (bgo#738663).
  - Checksum::ChecksumType: Remove erroneous documentation.
  - Property: Add some documentation (bgo#523043).
  + Gio: Add Resource.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 2.42.0:
  + Gio: Notification: Deprecate set_urgent().
  + Tools: h2def.py: fixed generator in case of inline functions
    (bgo#736427).
  + Build system fixes.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 2.41.4:
  + gmmproc:
  - Added parameter exception_handler in _WRAP_VFUNC()
    (bgo#735132).
  - Better error checks in some _WRAP_* macros.
  + Build:
  - Update and overhaul of Visual Studio 2010 and Visual Studio
    2008 project build files.
  - Gio::DBus: Don't use parameter name 'interface' to fix the
    build with MinGW (bgo#735137).
* Fri Aug 22 2014 dimstar@opensuse.org
- Update to version 2.41.3:
  + Updated documentation (bgo#734094).
* Tue Jul 29 2014 dimstar@opensuse.org
- Update to version 2.41.2:
  + Gio:
  - Menu: Allow detailed_action == null (bgo#733203).
  - Add Permission and SimplePermission (bgo#732436).
  + Glib:
  - Make custom interface properties instance data (bgo#732746).
  - PropertyBase: Use g_object_notify_by_pspec() instead of
    g_object_notify() (bgo#731484).
  + gmmproc:
  - Add support for GtkContainer child properties.
  - _WRAP_METHOD: Allow multi-word parameter types such as
    unsigned int.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 2.41.1:
  + Gio:
  - Application: Deprecate set_action_group().
  - DesktopAppInfo: Deprecate set_desktop_env().
  - Settings:  Deprecate list_schemas(), range_check() and
    property_schema().
  - TlsConnection: Deprecate [set|get]_use_system_certdb()
    and property_use_system_certdb().
  - VolumeMonitor: Deprecate adopt_orphan_mount().
  + Glib:
  - Keyfile: Deprecate one of the load_from_dirs() methods.
  - ValueArray: Deprecated.
  + tests: Test custom properties and an interface with properties.
  + Documentation: Add a blank line after @deprecated and @newin to
    help doxygen.
- Changes from version 2.41.0:
  + Glib:
  - Keyfile: Add save_to_file().
  - Add VariantDict.
  + Gio:
  - Action: Add parse_detailed_name() and
    parse_detailed_name_variant().
  - Application: Add the handle-local-options signal.
  - ApplicationCommandline: Add get_options_dict().
  - MenuModel: Add signal_items_changed().
  - MemoryInputStream: Add add_data() taking a sigc::slot,
    with a test.
  - Add Notification.
  - Settings: Add get_user_value() and get_default_value().
  - Socket: Add get/set_option().
  - TlsInteraction: Add invoke_request_certificate(),
    request_certificate(), request_certificate_async() and
    request_certificate_finish().
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 2.40.0:
  + VariantType: Fix typo in VARIANT_TYPE_BYTESTRING_ARRAY value.
  + gmmproc: Small improvement of enum documentation.
  + Windows: Update the visual Studio build files.
* Sat Apr  5 2014 zaitor@opensuse.org
- Update to version 2.39.93:
  + Glib:
  - Keyfile: Add save_to_file().
  - Add VariantDict.
  - Variant: Remove the now-unnecessary local
    g_variant_parse_error_quark() (bgo#727554).
  + Gio:
  - Application: Add the handle-local-options signal.
  - ApplicationCommandline: Add get_options_dict().
  - Settings: Add get_user_value() and get_default_value().
  - Socket: Add get/set_option().
  - TlsInteraction: Add invoke_request_certificate(),
    request_certificate(), request_certificate_async() and
    request_certificate_finish().
  + Build:
  - h2def.py:
    . Handle *_DEPRECATED_IN_* and AVAILABLE_IN_* with 0 digits.
    . Also strip *_DEPRECATE_IN_*_FOR () without a space.
  - Visual Studio Projects: Update giomm Projects.
* Wed Apr  2 2014 dimstar@opensuse.org
- Update to version 2.39.92:
  + Gio: Application: Add add_main_option_entry() and
    add_option_group().
  + Documentation: Glib::ustring: Say more clearly that it must be
    only UTF-8 (bgo#681560).
  + Build: win32: Surround content_type_get_symbolic_icon() with
    ifdefs.
* Wed Apr  2 2014 dimstar@opensuse.org
- Update to version 2.39.91:
  + Documenation: Improve Gio::Socket documentation.
* Wed Apr  2 2014 zaitor@opensuse.org
- Update to version 2.39.4:
  + Gio
  - Action:
    . Add parse_detailed_name() and
    parse_detailed_name_variant().
    . Fix activate(const Glib::Variant<T_Value>& value)
    (bgo#722896).
  - MenuModel: Add signal_items_changed().
  - MemoryInputStream: Add add_data() taking a sigc::slot,
    with a test (bgo#609946).
  - MenuModel: Add signal_items_changed().
  - Add Notification (bgo#722896).
  + Documentation:
  - Fix some doxygen warnings.
  - Don't change NULL to 0 in docs, when it's part of a longer
    name.
  - OptionContext: Add API documentation based on the C docs.
* Wed Apr  2 2014 zaitor@opensuse.org
- Update to version 2.39.3:
  + Documentation improvements.
  + Fix a test on IPv6 systems.
* Wed Apr  2 2014 dimstar@opensuse.org
- Drop old tarball.
* Mon Nov 18 2013 dimstar@opensuse.org
- Update to version 2.38.1 (bnc#849913):
  + Gio::ActionGroup: Remove a nonsensical check that clang
    complains about, correctly (bgo#709963).
  + Updated documentation.
* Fri Oct 11 2013 dimstar@opensuse.org
- Update to version 2.38.0:
  + Glib:
  - ByteArray:
    . Fix refcount problems.
    . Add some tests for methods returning self.
  + Gio:
  - Action:
    . Add an activate() method that takes no parameter.
    . print_detailed_name(): Remove the action_name parameter.
  - ActionGroup: activate_action(): Add a method overload that
    takes no parameter parameter.
  - ActionMap: Fix a reference-counting problem.
  - MenuItem:
    . Add set_action(), unset_target() and
    unset_action_and_target().
    . get/set_attribute(): Deprecated for
    get/set_attribute_value() methods.
  - Settings: Add create_action().
* Fri Sep 20 2013 dimstar@opensuse.org
- Update to version 2.37.93:
  + Gio:
  - ActionMap: lookup_action(): Fix the reference counting.
  - File: Add measure_disk_usage()
    and measure_disk_usage_async().
  - Settings: Add get/set_uint().
  - Add VariantParseError. Because it is thrown by GtkBuilder, at
    least for now.
  + Build fixes.
* Wed Sep 11 2013 dimstar@opensuse.org
- Update to version 2.37.7:
  + Gio: Menu: Add insert/append/prepend_section() with no label
    parameter.
  + gmmproc:
  - Pass NULL to C function calls for optional empty strings
    (bgo#686909, bgo#702456).
  - Add parameter return_value in _WRAP_VFUNC (bgo#705699).
  + Build: Update Visual Studio Projects.
* Wed Aug 28 2013 dimstar@opensuse.org
- Update to version 2.37.6:
  + Gio:
  - Action:
    . Make get_state() templated.
    . get_state_hint(): Correct a check.
    . Add templated change_state() and activate().
    . print_detailed_name() Make this templated.
  + ActionGroup: Add templated getters.
  + ActionMap: add_action_radio_*(): Use better Slot types.
  + SimpleAction:
  - Make set_state() protected.
  - add_action() now takes a slot with no parameter. Added
    add_action_with_parameter().
  + SimpleActionGroup:
  - lookup(): Add a const version and use refreturn.
  - Deprecate all methods, because they just call methods in the
    base ActionMap. The C functions are now deprecated too
    (bgo#705600).
  + gmmproc: Fix _WRAP_SIGNAL with 'ifdef' and 'deprecated'.
* Tue Aug  6 2013 dimstar@opensuse.org
- Update to version 2.37.5:
  + Object: Add interfaces to custom types before class_init.
  + DateTime: Fix compare() and equal() (bgo#704639).
  + Regex: Add get_max_lookbehind().
  + Variant: Fix memory leaks (bgo#704851).
  + Gio:
  - Action:
    . get_state() and get_state_hint() now return something.
    . Add get_state_bool() and change_state(bool).
    . Add create_radio_string() and create_radio_integer() for
    radio items, though we might change this API lots.
  - ActionMap:
    . Add add_action(name, slot).
    . Add add_action_radio_string() and
    add_action_radio_integer() for radio items, though we might
    change this API lots.
  - Application: Add mark/unmark_busy().
  - DesktopInfo: Add list_actions(), launch_action() and
    get_action_name().
  - File: Add trash_async(), trash_finish(),
    make_directory_async() and make_directory_finish().
  - Menu: Add remove_all().
  - MenuItem:
    . Add set/unset_icon().
    . Reimplement the constructors (bgo#705199).
  - SimpleAction:
    . set_enabled(): Add default parameter value.
    . Add constructors and create_bool() methods that take a bool
    instead of a VariantBase for the state, to make it easier
    to deal with toggle actions.
  + Updated documentations.
  + Build fixes.
* Wed Jul 10 2013 dimstar@opensuse.org
- Update to version 2.37.4:
  + glibmm: Use std::memset() instead of GLIBMM_INITIALIZE_STRUCT.
  + giomm: Add Gio::DBus::InterfaceSkeleton.
  + gmmproc:
  - docextract_to_xml.py: Add '&rArr;' to the list of escape
    sequences.
  - Add _WRAP_ENUM_DOCS_ONLY() and simplify enum docs process
    (bgo#703155).
  - gmmproc: Use GMMPROC_RETURN_MISMATCHES environment variable.
  - Write glibmm version in generated files (bgo#697835,
    bgo#700495).
  + Build: Move to a generated ChangeLog.
* Thu May  2 2013 dimstar@opensuse.org
- Update to version 2.36.2:
  + Revert this change from 2.36.1, which should not have appeared
    in a stable release yet:
  - Custom Interfaces: Implement derived interface properties.
* Wed May  1 2013 dimstar@opensuse.org
- Update to version 2.36.1:
  + Custom Interfaces: Implement derived interface properties.
  + gmmproc: Fix _WRAP_SIGNAL(custom_c_callback) for void func().
  + Output.pm: convert_args_c_to_cpp(): Reverse mappings hash
    correctly.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 2.36.0:
  + GLib:
  - ByteArray:
    . Add size() and get_data().
    . Add a Glib::Value<> template specialization.
  - VariantBase: Add check_format_string().
  + Gio:
  - ApplicationCommandLine: Add get_stdin() and
    create_file_for_arg().
  - AsyncResult: Added is_tagged().
  - Credentials: Add get_unix_pid().
  - DesktopAppInfo: Add has_key(), get_string() and
    get_boolean().
  - FileEnumerator: Add get_child().
  - FileInfo: Add get_deletion_date().
  - SocketClient: Add get/set_tls(),
    get/set_tls_validation_flags(), get/set_proxy_resolver().
  + gmmproc:
  - Verify that void methods should not return a value
    (bgo#696364).
  - Parse the argument list of methods correctly.
  + Build:
  - Visual Studio Projects: Fix and update.
  - Add a test of implementing an interface, to detect the
    problem in glib 2.36.0 and the expected problem with
    glib >= 2.37.0 (bgo#697229).
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 2.35.9:
  + Glib:
  - Add edByteArray, because it is used in the GTls* API.
  - AppInfo::get_all(): Fix ownerships (bgo#694505).
  + Gio:
  - TlsFileDatabase: Add the create() method.
  - TlsCertificate: Add the certificate property.
  - TlsClientConnection: Add get_accepted_cas() and the
    "accepted-cas" property.
  - TlsDatabase: Add the lookup_certificates_issued_by*() methods
    and virtual functions.
  - TlsInteraction: Add the virtual functions.
* Tue Feb 26 2013 dimstar@opensuse.org
- Update to version 2.35.8:
  + Glib:
  - Resolver: Add lookup_records(), lookup_records_async() and
    lookup_records_finish().
  - Signal*::connect(): Make them less thread-unsafe (bgo#396958)
  - Threads: Add create(slot, name) to create named threads
    (bgo#689863).
  - Variant: Allow containing complex types in arrays and in
    variants.
  - Variant: Don't refsink variants created using the custom cast
    ctor.
  - Variant< std::vector<std::string> >: Add
    create_from_object_paths().
  - VariantBase: Add operator for BoolExpr (const void*)
    (bgo#690121).
  - VariantType: Add create_tuple() (bgo#688682).
  - VariantType: Correct the referencing in the create*() methods
    (bgo#688440).
  + Gio:
  - AppInfo: Add create_duplicate().
  - DesktopAppInfo: Add some new getter methods.
  - File: Remove refreturn to avoid memory leaks (bgo#691606).
  - MemoryOutputStream: Add the steal_as_bytes() method.
  - SimpleAction: Fix stateful action constructor typo, allowing
    use (bgo#690122).
  - SocketConnection: Add connect*() and is_connected() methods.
  - ThemedIcon: Wrap the "names" property.
  - Add TlsConnection, TlsClient, TlsServer, TlsDatabase,
    TlsCertificate, TlsPassword, TlsFileDatabase and
    TlsInteraction.
  - UnixConnection: Add
    [receive|send]_credentials_[async|finish]().
  + Gio::DBus:
  - DBus::[Connection|Proxy]: Use ifdefs for the UnixFDList
    call*() methods.
  + gmmproc:
  - _WRAP_VFUNC: Support the wrapping of slots.
  - _WRAP_METHOD: Support wrapping methods with slots.
  - _WRAP_METHOD: Ensure that slot parameters can be optional.
  - _WRAP_[CREATE|CTOR|METHOD]: Allow any order of {} options.
  - _WRAP_ENUM: Skip enum constants whose names are deleted.
  - _WRAP_CTOR: Handle *_new() functions with a final GError**.
  + Updated documentations.
  + Build fixes.
* Mon Nov  5 2012 dimstar@opensuse.org
- Update to version 2.34.1:
  + Gio:
  - Corrected an ABI class-size break in MountOperation.
  - ContentType: Actually implement
    content_type_get_symbolic_icon() name.
  + gmmproc:
  - Improve documentation generation.
* Mon Oct 22 2012 zaitor@opensuse.org
- Update to version 2.34.0:
  + Some minor documentation improvements.
- Drop packaging INSTALL file, as this is not needed for an rpm.
* Wed Oct 17 2012 zaitor@opensuse.org
- Update to version 2.33.14:
  + Glib:
  - RegEx: Add get_has_cr_or_lf().
  - VariantIter: Add init() method.
  + Gio:
  - ActionGroup: Add the query_action() methods.
  - FileAttributeMatcher: Add create_difference() and to_string().
  - FileInfo:  Add has_namespace(), [get|set]_attribute_status(),
    and [get|set]_attribute_strings().
  - IOStream: Add splice_async() splice_finish().
  + MenuItem:
  - Add get_attribute().
  + MountOperation:
  - Wrap the "show-unmount-progess" signal.
  + Proxy: Add call(), call_sync() and call_finish() for
    unix_fd_list.
  + gmmproc:
  - Make the output param feature work for single indirection.
    bgo#662371.
  - Add 3-argument @newin.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 2.33.13:
  + Build:
  - Use std::time_t instead of ::time_t instead of ::time_t.
  - Use std::size_t and std::ptrdiff_t instead of ::size_t and
    ::ptrdiff_t.
  + Gio:
  - AppLaunchContext: Add setenv(), unsetenv() and
    get_environment().
  - File: Add remove_async() and remove_finish().
  - Add e ConverterInputStream and ConverterOutputStream.
  - Add PollableInputStream and PollableOutputStream.
  + Gio::DBus:
  - Connection: Add the call_[finish|sync]() with UnixFDLists.
    (bgo#662371)
  + gmmproc:
  - Add a _NO_WRAP_INIT_REGISTRATION macro (bgo#684006)
  - _CLASS_GOBJECT: Allow classes to have custom wrap()
    functions (bgo#684006)
  - _WRAP_METHOD: Allow setting parameters from C output params.
    (bgo#662371)
  - Prepend a Doxygen @throws clause to the declaration of
    virtual functions that throw Glib::Error.
  - Improve the search for unwrapped methods.
* Mon Sep 10 2012 dimstar@opensuse.org
- Update to version 2.33.12:
  + Gio:
  - Add Converter, ZlibCompressor, ZlibDecompressor and
    CharsetConverter classes.
  - AppInfo: Added  get_display_name(),
    set_as_last_used_for_type() and get_supported_types().
  - Application: Added get_dbus_connection() and
    get_dbus_object_path().
  - ContentType:
    . get_icon(): Fix a refcount error.
    . Added get_symbolic_icon().
  - DBusAuthObserver: Added allow_mechanism().
  - Drive: Added get_symbolic_icon().
  - FileInfo: Added get_symbolic_icon().
  - Menu: Added append_section().
  - MenuItem: Added get_link().
  - MenuModel: Added is_mutable() and get_n_items().
  - Mount: Added get_symbolic_icon().
  - ProxyAddress: Added get_destination_protocol() and get_uri().
  - Socket: Added get_available_bytes(), get_ttl(), set_ttl(),
    get_broadcast(), set_broadcast(), get_multicast_loopback(),
    set_multicast_loopback(), get_multicast_ttl(),
    set_multicast_ttl(), join_multicast_group(),
    leave_multicast_group() and properties.
  - Volume:
    . Added get_symbolic_icon().
    . Added get_sort_key().
  + gmmproc:
  - _WRAP_VFUNC: Handle virtual functions that throw GErrors.
    (bgo#683460)
- Changes from version 2.33.4:
  + Glib:
  - KeyFile: Correct the load_from_dirs() implementation.
  - Variant: Make sure that we always sink the initial reference.
    (bgo#680407)
  - VariantType: peek_string(): Correct this to handle the
    non-null-terminated result from g_variant_type_peek_string().
  - Threads::Mutex, RecMutex: Add wrap() functions (bgo#483790)
  + gmmproc:
  - Add _CUSTOM_CTOR_CAST
  + Updated documentation (bgo#670212)
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 2.33.3:
  + Glib: Added the Bytes class, wrapping GBytes.
  + Gio:
  - InetSocketAddress: Added get_flowinfo() and get_scope_id()
  - OutputStream: Added write_bytes(), write_bytes_async() and
    write_bytes_finish().
  - InputStream: Added read_bytes(), read_bytes_async() and
    read_bytes_finish().
  + Gio::DBus: Connection: Added get_last_serial()
  + gmmproc: Add _INCLUDE_IN_WRAP_INIT, _GMMPROC_WRAP_CONDITIONALLY
* Sun Jul 15 2012 dimstar@opensuse.org
- Update to version 2.33.2:
  + Added some enum values and documentation.
- Changes from version 2.33.1:
  + Gio:
  - Application:
    . Allow the application ID to be empty.
    . Pass 0 (NULL) rather than "" to GApplication.
  - Add Resource (bgo#674545)
  + Glib:
  - Miscutils: get_system_data_dirs(), get_system_config_dirs():
    Return early when the C function returns NULL.
  - Thread::RecMutex: Don't initialize this as a GStaticMutex.
    (bgo#677291)
  - Documentation: Don't hide add_exception_handler()
    documentation.
* Sat Jul 14 2012 zaitor@opensuse.org
- Update to version 2.32.1:
  + Gio:
  - Application: Pass 0 (NULL) rather than "" to GApplication.
  + Glib:
  - Miscutils: get_system_data_dirs(), get_system_config_dirs():
    Return early when the C function returns NULL.
  - Thread::RecMutex: Don't initialize this as a GStaticMutex.
    (Deprecated anyway) (bgo#677291).
  + Documentation:
  - Don't hide add_exception_handler() documentation.
  - Really hide the GCheckSum type from the documentation.
* Tue Apr 10 2012 vuntz@opensuse.org
- Update to version 2.32.0:
  + Glib:
  - Dispatcher: Don't send messages to a deleted Dispatcher
    (bgo#651942).
  - Make SignalTimeout/SignalIdle::connect_once() more thread
    safe (bgo#396963).
  - Document Glib::Property and Glib::PropertyBase (bgo#673291).
  + gmmproc:
  - Add macro _CUSTOM_CTOR_CAST in _CLASS_BOXEDTYPE (bgo#511136,
    comment 20).
  - Generate the documentation of default constructors of
    interface classes (bgo#673213).
  + Build:
  - Update Visual Studio projects.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 2.31.22:
  + Glib:
  - Threads, Dispatcher: Delete DispatchNotifier (bgo#671587).
  + Gio:
  - Action: Ensure vfunc callbacks return valid memory.
  - ActionGroup: list_actions_vfunc(): Do not return freed
    memory.
  - Move AppLaunchContext into its own header file.
  - Add Menu and MenuItem.
  - SimpleAction: Constructor: Add a parameter that takes no
    VariantType.
  + Gio::DBus:
  - Object: Ensure vfunc callbacks return valid memory.
  - Add the Interface and Object interfaces.
  + gmmproc:
  - _WRAP_SIGNAL() can now take an optional deprecated parameter,
    like _WRAP_METHOD() and _WRAP_PROPERTY().
  - _WRAP_PROPERTY(): Correct the ifdefs in generated code when
    using the optional deprecated parameter.
  + Other:
  - Dispatcher examples: Use Glib::signal_idle().connect_once()
    (bgo#396963).
  - Some fixes for minor clang++ warnings.
* Thu Mar  8 2012 vuntz@opensuse.org
- Update to version 2.31.20:
  + Glib:
  - Fix exceptions thrown by Thread::create() and
    Threads::Thread::create (bgo#640029).
  - Fix the build with --disable-deprecated-api (bgo#640029).
  + Gio:
  - Application: Add quit().
  + Gio::DBus:
  - DBus::Error, DBus::Proxy: Fix interaction with
    generate_wrap_init.pl (bgo#640029).
  - Documentation: Signal*: Better description of the connect*()
    methods (bgo#669906).
  + gmmproc and tools:
  - gmmproc: Allow destructors to be documented (bgo#668918).
  - docextract_to_xml.py: Generate signal documentation too
    (bgo#668918).
  - Add some scripts to regenerate the .defs files.
  - generate_wrap_init.pl: Improve reg. of exception classes in
    sub-namespaces and improve it for deprecated files and
    sub-namespaces (bgo#640029).
  - h2defs.py: Ignore the new GDK_AVAILABLE_IN_* macros.
* Mon Feb 27 2012 vuntz@opensuse.org
- Update to version 2.31.18.1:
  + gmmproc:
  - h2def.py: Handle types such as 'const gchar* const *' for
    functions.
  - _WRAP_PROPERTY(): Allow properties to be deprecated.
  + Gio:
  - Application: Derive from the ActionGroup interface.
  - Application: Add missing virtual functions and
    get/set_default() methods.
  - Add MenuModel, MenuAttribute, MenuLink and MenuIter.
  + Gio::DBus:
  - ActionGroup, MenuModel: Have get() methods instead of
    create() methods (bgo#637445).
  - Add DBus::MenuModel.
  - Connection: Add the MenuModel export/unexport methods.
  - Add class documentation.
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 2.31.18:
  + Gio:
  - Add the ActionMap interface.
  + Gio::Dbus:
  - Add the ActionGroup classe.
  - Connection: Add the ActionGroup export/unexport methods.
  + Glib:
  - Add the RemoteActionGroup classes.
  + gmmproc:
  - h2def.py: Handle deprecated functions.
  - docs: Remove possible parenthesis in gtk-doc signal
    references (bgo#668918).
* Wed Feb 15 2012 vuntz@opensuse.org
- Update to version 2.31.16.1:
  + gmmproc (docs):
  - Add documentation to wrapped signals (bgo#668918).
  - Convert signal and property names correctly (bgo#668918).
  - Add some HTML entity conversions.
  - Translate the <itemizedlist> tags in docs correctly.
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 2.31.16:
  + Build:
  - Dispatcher: Fix the build on win32.
  - thread.h: Move calls to deprecated glib functions into
    thread.cc.
- Remove xz BuildRequires now that it comes for free in the build
  system.
* Fri Nov 25 2011 dimstar@opensuse.org
- Update to version 2.31.2:
  + glibmm:
  - Add Glib::Threads::* in threads.h, deprecating everything in
    thread.h.
  - Avoid compiler warnings when using -std=c++0x with g++.
  + giomm:
  - drive: Add get_sort_key().
  - EmblemedIcon: Add clear_emblems().
  - FileIcon: Add the "file" property.
  - InetAddress: Add address_equal().
  - Mount: Add get_sort_key().
  - Socket: Add the "timeout" property.
  - SocketAddress: Add the "family" property.
  + gmmproc:
  - C example code removal: Also remove code in </programlisting>
    tags.
  - Ensure template parameter has a space before to avoid
    trigraphs. [bgo#663303]
  + Examples:
  - Avoid use of the now-deprecated API.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Fri Oct 28 2011 dimstar@opensuse.org
- Update to version 2.31.0.2:
  + gthread.h: Move the deprecation ifdefs to avoid affecting
    non-deprecated API.
* Fri Oct 28 2011 dimstar@opensuse.org
- Update to version 2.31.0.1:
  + Avoid deprecation compiler warnings in glibmm and projects
    using glibmm.
  + Move IOCondition from main.h to iochannel.h.
  + Don't include <glibmm.h> via init.h or wrap_init.h.
  + gmmproc:
  - Don't include C code examples found in the XML docs
  - Don't include <glibmm.h> by default in generated files.
  + Bugs fixed: bgo#650544, bgo#662597
- Changes from version 2.31.0:
  + Glib:
  - Date: set_time(): Use g_date_set_time_t() instead of
    g_date_set_time().
  - Thread: Deprecated thread_init(), Thread::joinable(),
  * _priority(), etc.
  - Threads are always enabled in glib now, and thread_init()
    does nothing.
  - VariantContainerBase: Add create_maybe().
  + Gio:
  - DataInputStream: Add read_line_utf8() and
    read_line_finish_utf8().
  - DBus::MethodInvocation: Add UnixFDList return_value() method
    overload.
  - Re-add Application and related class so they can be finished.
  - ApplicationCommandLine: Add the get_platform_data() method.
  - SimpleAction: Wrap the signals and properties.
  + gmmproc:
  - Fix h2def.py not parsing function starting with G_GNUC_*
    macros. [bgo#660225]
  - _WRAP_METHOD: Allow return types to have commas. [bgo#661401]
  - _WRAP_METHOD: Use {OUT} instead of {RET} for output params.
  - Remove M4 warnings due to commas in return types.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 2.30.0:
  + giomm:
  - DBus::Server: Add constructors.
  - Remove Application and friends, because they are still not
    ready.
  + Documentation:
  - gmmproc: DocParser: Correct the removal of link tags.
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 2.29.13:
  + giomm:
  - Variant< std::vector<std::string> >: Ensure correct creation
    (bgo#657030).
  + gmmproc:
  - Correct handling of constversion etc. in _WRAP_METHOD,
    avoiding side-effects on other _WRAP_METHOD() calls in the
    same .hg file (bgo#657751).
* Wed Aug 31 2011 vuntz@opensuse.org
- Update to version 2.29.12:
  + Gio::Application:
  - Add back Gio::Application and friends so we can try to finish
    them.
  - local_command_line_vfunc(): Use references for parameters
    (bgo#643478).
  + Gio::TimeZoneMonitor: Remove because it was removed in glib.
  + Build: configure: Require the latest libsigc++ because our
    tests require it (lp#829596).
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 2.29.11:
  + Gio::AppInfo:
  - launch(): Use a vector instead of a ListHandle and assume
    that it contains Gio::File rather than strings. This was
    unusable before.
  - Add launch() overload with no launch_context parameter.
  - Add launch() overload taking one file.
  - launch_uri(): Deprecate the method taking a
    GAppLaunchContext*, adding one taking a Gio::AppLaunchContext
    instead.
  - Add launch_uri() taking one URI.
  + Add test case for a recent fix in libsigc++ with RefPtr
    (bgo#564005).
  + tools: Add python .def generation scripts removed from
    PyGObject.
  + gmmproc: Allow _STRUCT_NOT_HIDDEN to be used even when multiple
    classes are defined in one file.
* Wed Jul  6 2011 vuntz@opensuse.org
- Update to version 2.29.10:
  + Gio:
  - Added DateTime, TimeZone, TimeZoneMonitor.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 2.28.2:
  + gmmproc:
  - _WRAP_METHOD: Add optional parameter functionality.
  - _WRAP_[CREATE|CTOR|METHOD]: Support parameter reordering.
  - _WRAP_METHOD: Add the possibility of an output parameter.
  - Protect documentation with m4 quotes.
  + Gio:
  - bgo#645072: DBus::Connection::emit_signal(): Replace empty
    strings with 0, because gio fails with "".
  + Build:
  - bgo#652461: Removed now-unused doctooldir variable from
    pkgconfig files.
* Wed May 18 2011 dimstar@opensuse.org
- Update to version 2.28.1:
  + gmmproc:
  - Extra Defs Tool: Only generate properties that the GType owns
  - bgo#649182: Put guards around generated includes in
    wrap_init.cc to fix the wind32 build.
  - bgo#644037: GtkDefs::split_tokens(): Speed improvement.
  + Build fixes.
  + Updated documentation.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 2.28.0:
  + Gio:
  - DBus::Connection:
    . Added a register_method() overload with no vtable.
    . register_object(), register_subtree(): Take the VTable by
    reference, not pointer.
  - DBus::MethodInvocation:
    . get_parameters(): Return a VariantContainerBase instead of
    taking a VariantBase.
    . return_gerror(), return_error_literal(): Rename them both
    to return_error().
  - DBus::NodeInfo::lookup_interface(): Add a method overload
    with no name.
  - DBus::Proxy: Rename type_map_changed_properties to
    MapChangeProperties.
  - DBus::VariantContainerBase::create_tuple(): Add a method
    overload that takes a single VariantBase.
  - Settings: Really add list_schemas().
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.27.99.2:
  + Glib:
  - Variant: Rename get(index) to get_child(index).
  - Variant<std::string>: Allow this to be used for object paths
    and signatures as well as just bytestrings.
  - Variant<Glib::ustring>: Allow this to be used for
    bytestrings, object paths and signatures as well as just
    (UTF-8) strings.
  - Move constructor definitions into the .cc file.
  - Capitalize the standard types, such as VARIANT_TYPE_STRING.
  + ArrayHandle: Make it compilable with MSVC 2005, 2008, 2010.
    bgo#645851.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.27.99.1:
  + Gio:
  - DBus: Use VariantContainerBase for tuple Variants.
* Thu Mar 24 2011 fcrozat@novell.com
- Update to version 2.27.99:
  + Gio:
  - Removed Application, ApplicationCommandLine, and ActionGroup
    because they are unfinished. We hope to add them back in
    glibmm 3.2.
  - Removed SettingsBackend because it is unfinished.
  - Settings: Removed API that used SettingsBackend.
  - Variant: Improved the documentation.
  + Build: Remove the dependency on mm-common during the tarball
    build.
- Changes from version 2.27.98:
  + Gio:
  - DBus::InterfaceVTable: Make the tuple type clearer in
    SlotInterfaceMethodCall.
  + Glib:
  - Correct some range checks to use >= instead of just >.
  - Vectorutils, ArrayHandle: Check for NULL pointers.
- Changes from version 2.27.97:
  + Gio:
  - DBus::Proxy: Added the properties_changed signal bgo#644886
  + Variant:
  - Added Variant<VariantBase>::get(). bgo#644207.
  - Added some get() method overloads.
  - Added VariantBase::cast_dynamic(). bgo#644146
  + Build: Fix the missing doc-install.pl problem.
    mm-common is now needed for tarball builds, though this might
    change soon.
- Changes from version 2.27.96:
  + Gio:
  - Application:
    . open(): Added a single-file method overload.
    . The command-line signal now returns an int instead of a
    bool. It is a main() status code.
    . Added get_environ().
    . Add the local_command_line vfunc,
  - ApplicationCommandLine: Use std::string instead of ustring in
    some API.
  - DBus::InterfaceVTable: Use g_error_copy() where appropriate,
    fixing a crash. bgo#644008
  + Build: Do not install doctool/ scripts such as doc-install.pl.
    These are now only installed by mm-common, and the mm-common
    macros find it there, so no changes should be necessary in
    other modules if you update mm-common.
  + Documentation: Avoid errors in the reference documentation due
    to encoding confusion in our perl scripts. bgo#644037
- Changes from version 2.27.95:
  + Gio:
  - Throw Gio::Error again, instead of just the base Glib::Error.
    This was broken in glibmm 2.27.94.
  + Glib:
  - build_filename(): Add method overloads to take up to 9
    arguments, for convenience. bgo#599578
  + Documentation: Mark some new API as new in 2.28.
* Wed Feb 23 2011 adam@mizerski.pl
- Update to version 2.27.94:
  + OptionGroup:
  - Add add_entry() that takes a slot with callback function
    (bgo#589197).
  - on_post_parse() overrides no longer need to call the base
    class (bgo#588988).
- Changes from version 2.27.93:
  + Added ArrayHandler, ListHandler and SListHandler, to help with
    conversions to/from std::vector.
  + Application: Initialize glibmm and giomm in the constructor,
    for convenience.
  + Resolver: lookup_service(), lookup_by_address(): Fix the
    reference counting (bgo#639575).
  + Fix the build (and of applications) with
    GLIB_DISABLE_SINGLE_INCLUDES.
- Changes from version 2.27.91.1:
  + gmmproc:
  - _WRAP_CTOR(): Restore the optional extra parameter, because
    it is still needed by gtkmm-2.4.
  - Added conversion from bool& to gboolean*.
  + DBus::[watch|own]_name(): Add default values for parameters.
  + DBusConnection:
  - Add a send_message() without an "out_serial" parameter.
  - Avoid errors/exceptions in callbacks due to NULL C strings.
  - Wrap properties and signals.
  + DBusMessage: Wrap properties and signals.
  + DBusServer: Comment out constructors because of bgo#639478.
  + InetAddress: Wrap properties.
  + Variant: Make the variant_type() functions return actual types.
  + Documentation: Started a client/server example that uses the
    user's bus.
- Changes from version 2.27.91:
  + Gio:
  - BufferedInputStream, BufferedOutputStream: Fix create_sized()
    (bgo#638616).
  - DBus: Use std::string for addresses since they could be a
    file path.
  - DBus: Use std::string instead of Glib::ustring for guid's
    since std::string's API is probably adequate enough for their
    use.
  - DBusConnection:
    . call*() methods: Re-order parameters.
    . Callbacks: Check for NULL GError** parameters and throw
    exceptions to the caller.
    . Add [register|unregister]_subtree() methods.
    . Fix crashes caused by inappropriate use of
    reinterpret_cast<> (bgo#637587).
  - DBusConnectionInvocation: reference-counting fixes.
  - DBusIntrospection: Fix some reference counting.
  - DBusServer:
    . Added create() methods.
    . CCorrect the type of the "active" property.
  - SocketService, ThreadedSocketService: Correct ref-counting
    for signals.
  - Improvements to the DBus examples.
  + Tools:
  - gmmproc: Warn about unwrapped properties.
  - Added defs_fixer.pl, which fixes some generated .defs by
    applying a specified override file.
- Changes from version 2.27.5.1:
  + Glib:
  - RefPtr: Make it work with sorted containers (bgo#626858).
  - Variant:
    . Make all he get_iter() methods const.
    . Added dictionary entry and dictionary specializations.
    . VariantContainerBase: Add a create() method from an array
    of variants.
    . Added tests.
  - gmmproc cleanup
  + Gio:
  - Application: Added the open signal.
  - DBusConnection: Add register/unregister_object() methods
    (bgo#637587).
- Changes from version 2.27.5:
  + Glib:
  - Added Variant<std::string>, Glib::Variant< array >, and
    Variant< vector > specializations
  + Gio:
  - Added DBus client example:
    examples/dbus/well-known-address-client.cc
  - Fix the build with mingw32 (bgo#636754).
- Change BuildRequires to pkgconfig() ones:
  + old ones: glib2-devel, libsigc++2-devel.
  + pkgconfig() ones: gio-2.0, glib-2.0, gmodule-2.0, gobject-2.0,
    sigc++-2.0.
- Pass --disable-static to configure.
* Thu Dec 16 2010 vuntz@opensuse.org
- Update to version 2.27.4.1:
  + Gio:
  - DBus[Connection|Proxy]: Don't take extra reference on async
    creation.
  - DBusConnection:
    . Add non-observable create method overloads.
    . Make the create methods.async get methods, static.
    . Added get_sync() methods.
    . Added send_message_with_reply_sync() methods.
    . Added signal_subscribe() and add_filter().
  - DBusIntrospection: new_for_xml(): Rename to create_for_xml().
  - DBusProxy:
    . Reorder the parameters so that "name" is second in methods.
    . Add a non-cancellable call_sync() method.
  - Documentation: Add a DBus Doxygen group.
  + Glib:
  - Regex: Add a MatchInfo class and use it. bgo#636911
  - gmmproc: Remove m4 conversion files for gdk, gtk, atk, and
    pango. They are now in the derived projects, which should
    now include convert_glibmm instead of, for instance,
    convert_gtkmm.
- Changes from version 2.27.4:
  + Gio:
  - DBus::Address: Wrap the gio dbus address API in this
    namespace.
  - DBusConnection:
    . Add emit_signal().
    . Add call(), call_finish() and call_sync() methods.
  - DBusMethodInvocationbusmethodinvocation: Remove the default
    constructor because it probably will not be used (there is no
    create() method to go along with it).
  - DbusServer: create_sync(): Use g_dbus_server_new_sync()
    instead of the constructors because the C function does more
    than call g_initable_new().
  + gmmproc:
  - Improve parsing of the C documentation.
- Changes from version 2.27.3.1:
  + Gio:
  - Added ApplicationCommandLine.
  - Application
    . Added non-cancellable overload of register_application()
    . Return int value from run() correctly
    . Fix protected constructor signature
  - DBusConnection, DBusProxy, DBusServer: Add non-cancellable
    overloads of the constructors and create methods.
    Renamed the create() synchronized methods to create_sync().
  - Initable: Add a non-cancellable overload of the init()
    method.
  - Documentation: Added lots of class and method documentation.
- Changes from version 2.27.3:
  + Gio:
  - Application: Added open().
  - ActionGroup: Added list_actions.
  - DataInputStream: Added read_upto(), read_upto_async() and
    read_upto_finish().
  - DBusConnection: Correct the AsyncInitable
    inheritance/implementation.
  - MemoryOutputStream: Added steal_data(), and a const
    get_data().
  - NetworkService: Added get_scheme(), set_scheme() and the
    property.
  - Socket: Added get_timeout(), set_timeout(),
    receive_with_blocking() and send_with_blocking().
  - SocketClient:
    . Add get_enable_proxy(), set_enable_proxy(), get_timeout(),
    set_timeout() and add_application_proxy().
    . Added connect_to_uri(), connect_to_uri_async() and
    connect_to_uri_finish().
  - SocketConnectable: socketconnectable.hg: Added
    proxy_enumerate() and a const enumerate().
  - Added UnixSocketAddress
  - UnixCredentialMessage, UnixFDMessage: Wrap properties
    properly.
  - giomm.h: Add includes of newly wrapped API.
  + Glib:
  - ObjectBase: Fixed compiler errors when the debug warnings are
    enabled at compile time.
- Changes from version 2.27.2:
  + Gio:
  - Added ActionGroup.
  - Application: Large API changes to match the changed C API.
  - DBusConnection: Reorder the parameters in the constructors
    and create methods so that the DBusConnection flag parameter
    has a default value.
  - DBusProxy: Added get_cached_property().
  + Glib:
  - Main: Add get_time(), deprecating get_current_time(), though
    this needs more work.
- Changes from version 2.27.0:
  + Gio:
  - AsyncInitable: Add create_finish().
  - DBusProxy:
    . Add call(), call_finish() and call_sync() methods.
    . Add properties and signals.
  - Variant: create methods: Remove the floating reference of the
    GVariants, correcting our memory management.
  + Glib:
  - Added get_system_data_dirs() and get_system_config_dirs().
  - Build: Fix a Windows build problem caused by the removal of
    the optional-API ifdefs.
- Changes from version 2.27.0:
  + Add Gio:Application.
- Changes the Obsoletes of glibmm2 and glibmm2-doc to be < instead
  of <=, now that we have a new upstream version.
* Wed Oct 27 2010 dmueller@suse.de
- Change glibmm provides/obsoletes to glibmm2 in libglibmm-2_4-1.
* Mon Oct 11 2010 vuntz@opensuse.org
- Update packaging to use the shared library packaging policy:
  + Create libglibmm-2_4-1 and libgiomm-2_4-1 subpackages.
  + Add Provides/Obsoletes for glibmm2 to libglibmm-2_4-1.
  + Update baselibs.conf accordingly.
- Update summaries and descriptions.
- Version the glibmm24-devel Obsoletes in devel subpackage.
* Tue Sep 21 2010 vuntz@opensuse.org
- Update to 2.25.5:
  + Gio:
  - Removed Application (removed in glib 2.26)
  - DBusMessage: Added create_from_blob(), set/get_byte_order(),
    get_header_fields(), bytes_needed(), to_blob(),
    to_exception(), get_locked(), lock() and copy().
  - NetworkAddress: Added get_scheme() and property.
  - Added Proxy, ProxyAddress and ProxyResolver.
  - Settings: Added reset(), list_children(), list_keys().
  - Added DBusAnnotationInfo, DBusArgInfo, DBusMethodInfo,
    DBusSignalInfo, DBusPropertyInfo, DBusInterfaceInfo, and
    DBusNodeInfo.
  - Added DBusProxy.
  - Added DBus::watch() and DBus::unwatch_name().
  - Several other DBus* improvements.
  + Glib:
  - Variant: Added get_maybe(), get_size(), get_data(), store(),
    and get_n_children().
  - Added VariantIter.
- Drop glibmm2-drop-gapplication.patch: fixed upstream.
* Sat Sep 18 2010 vuntz@opensuse.org
- Add glibmm2-drop-gapplication.patch: patch based on changes in
  git, to remove GApplication bindings, since the API was removed
  in glib 2.25.16.
* Wed Sep  1 2010 dimstar@opensuse.org
- Update to version 2.25.4:
  + Gio:
  - Added AsyncInitable.
  - DBusConnection: Added create() methods.
  - UnixConnection: Add receive/send_credentials() methods.
  - Added SocketControlMessage, UnixCredentialsMessage and
    UnixFDMessage.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.25.3:
  + Glib:
  - Added VariantBase and Variant<>.
  + Gio:
  - Added Application, wrapping GApplication
  - Added Credentials.
  - Added DBusConnection, DBusMethodInvocation, DBusServer,
    DBusAuthObserver and DBusMessage.
  - Added UnixFDList.
  + Build:
  - Fix the build without __STDC_ISO_10646__.
* Mon Aug  2 2010 dimstar@opensuse.org
- Update to version 2.25.2:
  + Gio: Settings: create*() methods:
  - Use SettingsBackend instead of string context parameters.
- Changes from version 2.25.1:
  + Glib:
  - Removed the --enable-api-exceptions, --enable-api-properties,
  - -enable-api-vfuncs and --enable-api-default-signal-handlers
    options because nobody needs them any more. The defines are
    now always defined, for backwards compatiblity.
  - Keyfile:
    . Added get_int64, get_uint64, set_int64, set_uint64().
    . Added load_from_dirs().
  - OptionGroup: Added set_translate_func().
  - RegEx: Added get_compile_flags(), get_match_flags().
  - bgo#617463: TimeVal: Avoid compiler warning in
    TimeVal::as_double()
  - bgo#578355: Added Glib::listenv().
  + Gio:
  - DesktopAppInfo: Added get_filename().
  - Added Settings, wrapping GSettings.
* Thu Jun 10 2010 wittemar@googlemail.com
- build 32bit-package
* Thu May  6 2010 dimstar@opensuse.org
- Update to version 2.24.2:
  + Reference Documentation: Add main page text for index.html
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.24.1:
  + bgo#615482: UnixOutputStream: Fix the constructor to use the
    correct property name.
  + Documentation: Strip out the gobject-introspection annotations,
    and use other improvements made to docextract_to_xml.py
  + Fix the Windows MSVC build.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.24.0:
  + No change compared to 2.23.4, just a version bump.
* Fri Mar 26 2010 vuntz@opensuse.org
- Update to version 2.23.4:
  + Gio:
  - File: Add TypeTraits to fix Gtk::FileChooser::get_files() in
    gtkmm. bgo#590940
  - MemoryInputStream: Correct data loss/corruption with binary
    data. bgo#609552
  - ThemedIcon: Added get_names().
  + Glib:
  - Fix ustring::format(non-const char*) and add regression test.
  + Build:
  - tests: Reorder assignment to LDADD and giomm_ldadd in
    tests/Makefile.am to always use the built library, not the
    installed one. bgo#610854
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.23.3:
  + Gio:
  - bgo#608269: AsyncResult: Add get_source_object_base(),
    deprecating get_source_object() because it usually can never
    work.
  - bgo#611521: File: Delete Gio::SlotFileProgress (and friends)
    at the correct time, fixing a crash.
  - bgo#607554: IOStream: get_input_stream(), get_output_stream()
    Fix reference counting, fixing a crash.
  - MemoryInputStream::add_data(): Minor documentation fix.
  - bgo#605710: MemoryOutputStream: Fix the constructor, so this
    really works.
* Mon Feb  8 2010 captain.magnus@opensuse.org
- Update to version 2.23.2:
  + Glib:
  - BalanceTree: New class, wrapping GTree.
  - NodeTree: get_root() const correction.
  + Gio:
  - Cancellable: Added release_fd() and make_polldf().
  + File:
  - Added has_parent(), supports_thread_contexts(),
    start_mountable(), stop_mountable(), poll_mountable()
  - Aded create_file_readwrite(),  create_file_readwrite_async()
  - Added open_readwrite(), open_readwrite_async(),
    finish_readwrite(), replace_readwrite(),
    replace_readwrite_async() and finish_replace_readwrite()
  - unmount_mountable(), eject_mountable(): Add overrides with
    MountOperation parameters
  + NetworkService: Change hostname property to domain
  + SocketConnection: Remove graceful-disconnect property
  + UnixInputStream: Fix the constructor's implementation.
    bgo#608665
  + Windows: giomm.h: Don't include files on Windows that are not
    available on that platform.
* Mon Jan 25 2010 captain.magnus@opensuse.org
- Update to version 2.23.1:
  + This release adds the BalancedTree class (wrapping GTree) and
    fixes a number of bugs.
  + bgo#594173: NodeTree::get_root() violates const-correctness
  + Fine-tune Doxygen configuration to improve output
  + Add non-cancellable versions of a bunch of SocketClient
    functions wrap g_socket_connection_factory_create_connection()
  + A bunch of minor doxygen cleanups around the tree
  + bgo#606146: Relax the glib requirement
  + bgo#581811: Gio::content_type_guess() miss the version with a
    NULL filename
  + bgo#606100: Fix wrapping properties
  + Implement GTree wrapper
* Wed Jan  6 2010 captain.magnus@opensuse.org
- Update to version 2.23.0:
  + This release adds API for the new Network I/O classes that were
    added in glib 2.22.x.
  + Re-enable network IO stuff, and wrap more of it
  + Added new files to MSVC projects
  + ifdef-out inclusion of files not available on Windows in
    giomm.h
  + Regenerate gio_methods.defs, bump glib requirement
  + Re-generate gio_docs.xml
  + Wrap Gio::Mount::get_default_location()
  + _IGNORE a couple API that we've implemented manually
  + Re-generate gio signal defs
  + Add some more .gitignore stuff
  + Make build successful when exceptions, vfuncs, etc. are
    disabled.
  + Regex: Slight documentation improvement.
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 2.22.1:
  + Fix KeyFile build with exceptions disabled
  + Build fixes.
- Changes from version 2.22.0:
  + Re-enable input file line markers in gmmproc
  + Fix broken test for empty _WRAP_METHOD argument
  + Allow the C documentation to be overridden
  + Slightly clean up gross Perl code in gmmproc.in
  + Correctly quote the extracted comment for M4
  + Enable verbose output of autoreconf
  + Do not complain about missing docs_override.xml
  + Support Automake silent rules
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 2.21.5:
  + This release is a release candidate for 2.22.0.  As such, some
    unfinished API has been disabled (notably the network IO
    classes that we were not able to finish in time).
  + Remove sigc from the Doxygen excluded symbols
  + Sanitize the Glib::Cond usage example
  + Officially deprecate GLIBMM_CHECK_PERL macro
  + Delete obsolete MAINTAINERS file
  + Implement Gio::Socket ctors using Gio::Initable
  + Add Network I/O classes to new documentation module
  + Disable network io stuff: punted to next release
* Wed Sep  2 2009 vuntz@novell.com
- Update to version 2.21.4.2:
  + Always build tools/ subdirectory (bgo#593518)
- This fixes the build of various other C++ bindings.
* Fri Aug 28 2009 vuntz@novell.com
- Update to version 2.21.4.1:
  + Reenable hierarchy graphs for each class
  + Remove header and footer HTML fragments
  + Use shared mm-common Doxygen style sheet
* Wed Aug 26 2009 dimstar@opensuse.org
- Update to version 2.21.4:
  + Transition to new mm-common build infrastructure
  + Correct the if condition in Gio::MemoryInputStream::add_data()
- Do no longer carry the tests in the -doc package.
- Merge the -doc into the -devel package. Provide -doc by -devel.
- Update install section to align with new build infrastructure.
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 2.21.3:
  + Only compile the properties example if properties are enabled.
  + Fails to install when bootstrapped with Automake 1.11
    (bgo#587173)
  + add _IGNORE() for a eject_with_operation() which is
    hand-written
  + add get_start_stop_type() and Gio::DriveStartStopType enum
  + add overloads for resolver methods without a cancellable object
  + add async versions of Resolver methods
  + Added a simple example showing how to resolve an internet
    address from a hostname
  + Fix MemoryInputStream::addData (bgo#589683)
  + Fix a build error in MemoryInputStream
  + Add Glib::ObjectBase::freeze_notify()/thaw_notify. (bgo#575533)
  + Repair Glib::KeyFile docs with regard to exceptions.
    (bgo#587766)
  + Wrapped several ISO 8601 related functions.
* Sun Jul 19 2009 vuntz@novell.com
- Update to version 2.21.2:
  + Glib:
  - Treat empty Glib::spawn*() working dir as unset
  - Add OptionGroup::add_entry(.., double&)
  + Gio:
  - Remove stray semicolons
  - Fix build with glib from master
  - wrap a couple added GDrive methods
  - Wrap g_drive_eject_with_operation() and related functions
  - implement GDrive::stop-button signal
  - implement Gio::InetAddress::get_native_size()
  - Implement Gio::Mount::mount/eject_with_operation()
  - implement Gio::Volume::eject_with_operation()
  - fix accidental bug in Gio::Drive::eject() that the compiler
    warned me about
  - implement Gio::VolumeMonitor::drive-stop-button
- Changes from version 2.21.1:
  + Glib:
  - Date: Constructor: Check for invalid dates.
  - Added Glib::ValueArray, for use in gstreamermm.
  - Added Glib::file_set_contents().
  - gmmproc:
    . Avoid problems with spaces in _DEFS() calls. bgo#586785.
    . Improve guessing of the *_get_type() function names from
    enum names. bgo#575870.
  + Gio:
  - Cancellable: Added connect() and disconnect().
  - Added FileIOStream.
  - Added InetAddress.
  - Added Initable.
  - Added IOStream.
  - Added NetworkAddress.
  - Added NetworkService.
  - Added Resolver
  - Added Socket.
  - Added SocketAddress.
  - Added SocketConnectable.
  - Added SrvTarget.
  - File::load_contents() Added overload without the etag_out
    parameter. bgo#581349.
  + Windows Build:
  - General Windows fixes.
  - Fix the build directly from git.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.20.0:
  + Documentation fixes.
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.19.8:
  + Added FILE_CREATE_REPLACE_DESTINATION enum value.
  + Added Error::TOO_MANY_OPEN_FILES error code.
  + Fix some compiler warnings about extra ;s.
- Remove -fno-strict-aliasing from CFLAGS.
- Remove AutoReqProv: it's default now.
* Sat Feb 21 2009 vuntz@novell.com
- Update to version 2.19.3:
  + New API:
  - BufferedInputStream: buffer_size property
  - BufferedOutputStream: buffer_size, auto_grow properties
  - DataInputStream: byte_order, newline_type properties
  - DataOutputStream: byte_order property
  - FilterInputStream: close_base_stream property,
    get/set_close_base_stream()
  - FilterOutputStream: close_base_stream property,
    get/set_close_base_stream()
  - UnixInputStream: fd and close_fd properties, get_fd(),
    get/set_close_fd()
  - UnixOutputStream: fd and close_fd properties, get_fd(),
    get/set_close_fd()
  + Make licenses consistent with eachother (library gpl vs. lesser
    gpl, etc)
  + Fixed some problems when building with exceptions disabled
  + Build fixes
* Mon Feb  2 2009 hfiguiere@suse.de
- Fix devhelp (bnc#410564)
- Split -doc package.
* Mon Feb  2 2009 mboman@suse.de
- Update to version 2.19.2:
  + File: Added make_directory_with_parents() method overload with no
    parameter. bgo#566003
  + NoteTree: Do not use a non-ASCII dash character in a comment, to
    avoid the MSVC++ warning C4819 with Visual Studio 2008.
  + spawn_*() functions: Added alternative API for when
    GLIBMM_EXCEPTIONS_ENABLED is not enabled.
  + uri_*() functions: Fix memory leak.
  + ustring: Add an overload which takes only a format string and no arguments
    to be substituted.
* Fri Jan 23 2009 vuntz@novell.com
- Drop glibmm2-includes.patch, not needed anymore.
- BuildRequires glib2, not gtk2.
- Minor cleanups and use fdupes
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.19.1:
  + Fix accidental ABI breakage in 2.19.0 caused by adding default handlers
    for new Gio::Drive signals
  + Wrapped new glib 2.19.x API
  - Gio::AppInfo: get_commandline(), can_delete(), do_delete(),
    reset_type_associations(), launch_default_for_uri()
  - Gio::Drive: new signals changed, disconnected, and eject_button
  - Gio::Icon: create(std::string), to_string()(),
  - Gio::Mount: guess_content_type_sync(), is_shadowed(), shadow(),
    unshadow()
  - Gio::content_type_from_mine_type();
  - Gio::DesktopAppInfo: create_from_keyfile()
  - Gio::Emblem: new class
  - Gio::EmblemedIcon: new class
  - Gio::MemoryOutputStream: new class
  + Bugs Fixed:
  - bgo#555743 - warning in glibmm
  - bgo#562716 - warning fixing cause more warnings.
  - bgo#396963 - Add Glib::signal_idle().connect_once()
- Remove glibmm2-bgo555743.diff. Fixed upstream
* Sat Nov 29 2008 hfiguiere@suse.de
- Add patch glibmm2-bgo555743.diff
  + fix warnings in installed header. bgo#555743
* Wed Oct 22 2008 maw@suse.de
- Update to version 2.18.1:
  + Bugs fixed: bgo#506410, bgo#529496, bgo#539891, bgo#555576,
    bgo#556315, and bgo#556387.
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.18.0:
  + Bug fixed: bgo#550789.
* Fri Sep 12 2008 maw@suse.de
- Update to version 2.17.3:
  + API changes:
  * Glib::Tree (wrapper around GNode) renamed to Glib::NodeTree
    to avoid confusion with GTree
  * Pass the node to the traversal the callback
  * Move TraverseFlags inside the NodeTree class
  + New API:
  * Added the drive_eject_button signal
  * Bugs fixed: bgo#423990, bgo#529496,  bgo#523043, and
    bgo#506410.
* Mon Aug 11 2008 maw@suse.de
- Update to version 2.17.1:
  + New API:
  * Gio::File: make_directory_with_parents(), query_file_type(),
    and monitor()
  * Gio::FileEnumerator: get_container()
  * Gio::Mount: guess_content_type() and
    guess_content_type_finish()
  * Gio:ThemedIcon: prepend_name()
  * Gio::Volume: get_activation_root()
  + Bug Fixes: bgo#512348, bgo#538803, bgo#540656, bgo#540875,
    bgo#542929, bgo#543292
  + Fix AppLaunchContext::get_display() and
    AppLaunchContext::get_startup_notify_id() to use a list of
    Gio::File, not filepath string; properly documented we know
    that this is correct; it's an API break but this function
    could nothave worked before
  * Added Keyfile example.
* Mon Jun 30 2008 maw@suse.de
- Update to version 2.17.0:
  + Added copy constructor and assignment operator, made GDate
    constructor visible
  + Added Glib::Tree, a wrapper for GNode, providing an N-ary tree
    container, more or less like a standard C++ container
  + bgo#529648 - give helpful warning message when library user
    forgets to initialize the library
  + bgo#529533 - Fix bug that prevented for Gio::Mount, Gio::Drive,
    and Gio::Volume from being wrapped for some backend
    implementations.
* Sun May 18 2008 aj@suse.de
- Do not BuildRequire devhelp.
* Wed Apr  2 2008 maw@suse.de
- Update to version 2.16.1:
  + Reference-counting bugfix in Gio::File::create() and
    Gio::File::replace()
  + Include Gio::Error header in headers that have API that can
    throw this exception
  + Improve documentation
  + Fix warning with g++ 4.3.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.16.0:
  + File: load_contents(), load_contents_finish(),
    load_partial_contents_finish():
    Use char*& instead of char** for contents
    Use std::string& instead of char**  for etag_out
    Added method overloads without cancellable.
  + Improved documentation: Mention exceptions instead of errors
* Mon Mar  3 2008 maw@suse.de
- Update to version 2.15.7:
  - Gio:
    + Removed most vfuncs, because they are not useful to
    application developers, and are a likely source of errors
    + DesktopAppInfo:
  * Added Added create(), create_from_file(), is_hidden()
    and set_desktop_env(); renamed new_from_file() to
    create_from_file()
  - File:
    + equal(), get_relative_file(), contains_file(): Take const File
    parameters
    + FileAttributeInfoList: Added dup()
    + Added query_filesystem_info_async() and
    query_filesystem_info_finish() because these were added to
    the C API
    + Renamed contains_file() to file_has_prefix() because this
    was changed in the C API
  - MemoryInputStream: Added add_data(const void* data, gssize len)
  - Mount: Really added signals
  - MountOperation: Wrapped the ask-question signal
  - Volume:
    + Added should_automount()
    + Really added signals
  - UnixOutputStream, DataOutputStream, DataInputStream: Made
    constructors protected
  - ThemedIcon: Added append_name() because this was added to the
    C API
  - Glib: Renamed uri_get_scheme() to uri_parse_scheme() because
    this was changed in the C API
  - Devhelp fixes,
* Tue Feb 19 2008 maw@suse.de
- Update to version 2.15.5:
  + Updates for the latest gio API changes
  + Bugs fixed: bgo#515133.
* Tue Jan 29 2008 maw@suse.de
- Update to version 2.15.3:
  + FilterInputStream: Really wrap this
  + VolumeMonitor: Workaround a crash in gio due to the
    eccentric use of the GType system to discover GVolumeMonitor
    implementations; see gio bug #511814
  + Added Gio::Error exception
  + Added more method overloads without optional parameters, and
    reordered more parameters to allow default values
  + giomm.h: Added includes
- Remove libtool archives
- Add glibmm2-includes.patch.
* Thu Jan 24 2008 maw@suse.de
- Update to version 2.15.2:
  + New giomm library (check for giomm-2.4 with pkg-config)
    in the glibmm tarball. This wraps the new gio API in glib
    2.15/16; this API could change considerably before the stable
    glibmm 2.16 is released
  + Fixes for compilation with gcc 4.3
  + Many other changes.
- Remove upstreamed glibmm-2.14.0-gcc43.patch
- s#%%run_ldconfig#/sbin/ldconfig#.
* Mon Nov 26 2007 maw@suse.de
- Update to version 2.14.2:
  + Glib::wrap(): Don't fail when wrapping an interface that is
    implemented by an unrecognized type
  + gmmproc: Add support for the new _CONFIGINCLUDE() macro.
* Wed Oct 17 2007 rguenther@suse.de
- Fix build with GCC 4.3.
* Mon Sep 17 2007 maw@suse.de
- Update to version 2.14.0:
  + Regex:
  * Add escape_string
  * Rename match_full() to match()
  * Rename match_all_full() to match_all()
  * Rename split_full() to split().
* Mon Jul 30 2007 maw@suse.de
- Update to version 2.13.9:
  * KeyFile: Added Added get_double(), set_double(), get_double_list()
  and set_double_list().
  (Murray Cumming)
* Wed Jul 11 2007 mauro@suse.de
- Update to version 2.13.8
- Added some new API that was added in glib 2.12
- Update docs for the new functions in the API
- Added regex classes w/examples.
* Tue Apr 10 2007 maw@suse.de
- Update to version 2.12.7
- Bug fixes, including bugzilla.gnome.org #386990 and #397167.
* Fri Jan 12 2007 sbrabec@suse.cz
- Spec file cleanup.
* Fri Dec  8 2006 maw@suse.de
- Move to /usr, and remove several hardcoded paths.
* Tue Oct 17 2006 jhargadon@suse.de
- update to version 2.12.2
- Fix for api-default-signal-handlers option
- win32: Remove unused source file from Visual Studio project
- Support optional ifdef parameters in the .hg macros,
  to allow, for instance the --enable-atk=no option,
  to disable the build and use of the atkmm API,
  for use in embedded environments.
* Tue Oct 10 2006 sbrabec@suse.cz
- Use Obsoletes (#211085).
* Tue Sep 26 2006 sbrabec@suse.cz
- Package renamed to glibmm2.
* Fri Sep 15 2006 jhargadon@suse.de
- update to version 2.12.0
- Added the --enable-api-default-signal-handlers option, for use in
  embedded environments that have reduced resources. See configure --help
  for the other subsets
- Value: Added init(const GValue*), so we can copy GValue instances
  of any type at runtime. Needed by the new branch of libgdamm
- Build: Added the --enable-api-default-signal-handlers option, for use in
  embedded environments that have reduced resources. See configure --help
  for the other subsets
- Fix implementation of Glib::Date::set_time_current() so
  that it doesn't set the date to Dec 31, 1969
- Added init(const GValue*), so we can copy GValue instances
  of any type at runtime. Needed by the new branch of libgdamm
- Added a #warning to warn about including X11/Xlib.h before a glibmm header,
  which would break things. Bug #316726 from Mert Tugcu and Javeed Shaikh
- Quote some m4 macros to avoid warnings
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 sbrabec@suse.cz
- Do not require devhelp.
* Tue Jan 17 2006 sbrabec@suse.cz
- Updated to version 2.8.3.
* Thu Dec  1 2005 gekker@suse.de
- Update to version 2.8.2
* Wed Sep  7 2005 sbrabec@suse.cz
- Updated to version 2.8.0 (GNOME 2.12).
* Wed Sep  7 2005 sbrabec@suse.cz
- Updated to version 2.7.3.
* Thu Aug  4 2005 sbrabec@suse.cz
- Updated to version 2.6.1.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Thu Feb 10 2005 sbrabec@suse.cz
- Added branch 2.4, package splitted, updated to version 2.4.7.
* Tue May 25 2004 ro@suse.de
- undeprecate where needed
* Thu Mar 18 2004 sbrabec@suse.cz
- Removed *.o files from documentation (#36348).
* Mon Feb 23 2004 sbrabec@suse.cz
- Call autoreconf.
* Tue Feb 17 2004 sbrabec@suse.cz
- Initial SuSE package version 2.2.8.
